#!/bin/ksh ~/.mgltools/pythonsh
########################################################################
#
#    Vision Network - Python source code - file generated by vision
#    Thursday 04 August 2011 15:01:55 
#    
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Daniel Stoffler, Michel Sanner and TSRI
#   
# revision: Guillaume Vareille
#  
#########################################################################
#
# $Header: /opt/cvs/CADD/workflows/visualization/visualization_0.1.1_pmvnet.py,v 1.2 2011/08/04 23:59:33 jren Exp $
#
# $Id: visualization_0.1.1_pmvnet.py,v 1.2 2011/08/04 23:59:33 jren Exp $
#


if __name__=='__main__':
    from sys import argv
    if '--help' in argv or '-h' in argv or '-w' in argv: # run without Vision
        withoutVision = True
        from Vision.VPE import NoGuiExec
        ed = NoGuiExec()
        from NetworkEditor.net import Network
        import os
        masterNet = Network("process-"+str(os.getpid()))
        ed.addNetwork(masterNet)
    else: # run as a stand alone application while vision is hidden
        withoutVision = False
        from Vision import launchVisionToRunNetworkAsApplication, mainLoopVisionToRunNetworkAsApplication
	if '-noSplash' in argv:
	    splash = False
	else:
	    splash = True
        masterNet = launchVisionToRunNetworkAsApplication(splash=splash)
    import os
    masterNet.filename = os.path.abspath(__file__)
from traceback import print_exc
## loading libraries ##
from Pmv.VisionInterface.PmvNodes import pmvlib
from Vision.StandardNodes import stdlib
try:
    masterNet
except (NameError, AttributeError): # we run the network outside Vision
    from NetworkEditor.net import Network
    masterNet = Network()

masterNet.getEditor().addLibraryInstance(pmvlib,"Pmv.VisionInterface.PmvNodes", "pmvlib")

masterNet.getEditor().addLibraryInstance(stdlib,"Vision.StandardNodes", "stdlib")

try:
    ## saving node AutoDock VS Result Directory ##
    from Vision.StandardNodes import DirBrowserNE
    AutoDock_VS_Result_Directory_28 = DirBrowserNE(constrkw={}, name='AutoDock VS Result Directory', library=stdlib)
    masterNet.addNode(AutoDock_VS_Result_Directory_28,47,27)
    AutoDock_VS_Result_Directory_28.inputPortByName['directory'].widget.set(r"visualization_0.1.1_input", run=False)
    apply(AutoDock_VS_Result_Directory_28.configure, (), {'paramPanelImmediate': 1})
except:
    print "WARNING: failed to restore DirBrowserNE named AutoDock VS Result Directory in network masterNet"
    print_exc()
    AutoDock_VS_Result_Directory_28=None

try:
    ## saving node GetReceptors ##
    from Vision.StandardNodes import Generic
    GetReceptors_29 = Generic(constrkw={}, name='GetReceptors', library=stdlib)
    masterNet.addNode(GetReceptors_29,47,123)
    apply(GetReceptors_29.addInputPort, (), {'singleConnection': True, 'name': 'dir', 'cast': True, 'datatype': 'string', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white', 'originalDatatype': 'None'})
    apply(GetReceptors_29.addOutputPort, (), {'name': 'receptors', 'datatype': 'list', 'height': 12, 'width': 12, 'shape': 'oval', 'color': 'cyan'})
    apply(GetReceptors_29.addOutputPort, (), {'name': 'receptor_paths', 'datatype': 'list', 'height': 12, 'width': 12, 'shape': 'oval', 'color': 'cyan'})
    code = """def doit(self, dir):
    import glob, os
    match_str = '''*'''
    if dir is not None:
        cwd = os.getcwd()
        os.chdir(dir)
    try:
        pdirs = glob.glob(match_str)
        receptors = []

        for i in pdirs:
            if os.path.exists(i + os.sep + '''summarize_results.txt'''):
                receptors.append(i)

        receptor_paths = [os.path.join(dir, x) for x in receptors]

        if receptor_paths != []:
            self.outputData(receptors=receptors, receptor_paths=receptor_paths)
        else:
            receptor = glob.glob("*.gpf")[0].split('''.''')[0]
            receptors = [receptor]
            receptor_paths = [os.path.join(dir, receptor + ".pdbqt")]
            self.outputData(receptors=receptors, receptor_paths=receptor_paths)
    finally: 
        if dir is not None:
            os.chdir(cwd)



























"""
    GetReceptors_29.configure(function=code)
    apply(GetReceptors_29.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
except:
    print "WARNING: failed to restore Generic named GetReceptors in network masterNet"
    print_exc()
    GetReceptors_29=None

try:
    ## saving node ReceptorList ##
    from Vision.StandardNodes import ScrolledListNE
    ReceptorList_30 = ScrolledListNE(constrkw={}, name='ReceptorList', library=stdlib)
    masterNet.addNode(ReceptorList_30,47,189)
    apply(ReceptorList_30.inputPortByName['selection'].widget.configure, (), {'choices': ['2HTY_A', '2HU4_B']})
    ReceptorList_30.inputPortByName['selection'].widget.set(r"", run=False)
    code = """def doit(self, valueList, nameList, selection):
    widget = self.inputPorts[2].widget

    if self.firstRun is True:
        selection = None
        self.firstRun = False

    # do we run the first time, and have been restored from a network? (then
    # we have both valueList and selection specified)
    if valueList and selection and self.firstRun is True:
        self.firstRun = False
        self.objectList = valueList
        self.nameList = nameList
        data = self.getData(selection, nameList)
        if data is not None:
            self.outputData(selection=data)
        return

    # only rebuild widget if we receive a new valueList
    if self.inputPorts[0].hasNewValidData() or self.inputPorts[1].hasNewValidData():
        if valueList != self.objectList or self.nameList != nameList:
            self.objectList = valueList
            self.nameList = nameList
            if nameList:
                vList = nameList
            else:
                vList = []
                for data in valueList:
                    if type(data) == types.StringType:
                        vList.append(data)
                    else:
                        vList.append(repr(data))
            if widget is not None:
                widget.setlist(vList)
                widget.configure(choices=vList)
                widget.widget.setentry('''''')
            return

    if selection:
        data = self.getData(selection, nameList)
        if data is not None:
            self.outputData(selection=data)



"""
    ReceptorList_30.configure(function=code)
    apply(ReceptorList_30.configure, (), {'paramPanelImmediate': 1})
except:
    print "WARNING: failed to restore ScrolledListNE named ReceptorList in network masterNet"
    print_exc()
    ReceptorList_30=None

try:
    ## saving node LoadMolecule ##
    from NetworkEditor.macros import MacroNode
    LoadMolecule_31 = MacroNode(name='LoadMolecule')
    masterNet.addNode(LoadMolecule_31, 186, 608)
    output_Ports_33 = LoadMolecule_31.macroNetwork.opNode
    apply(output_Ports_33.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
    from Vision.StandardNodes import Generic
    getMolePath_34 = Generic(constrkw={}, name='getMolePath', library=stdlib)
    LoadMolecule_31.macroNetwork.addNode(getMolePath_34,217,82)
    apply(getMolePath_34.addInputPort, (), {'singleConnection': True, 'name': 'mol', 'cast': True, 'datatype': 'string', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white', 'originalDatatype': 'None'})
    apply(getMolePath_34.addInputPort, (), {'singleConnection': True, 'name': 'mol_paths', 'cast': True, 'datatype': 'list', 'defaultValue': None, 'required': True, 'height': 12, 'width': 12, 'shape': 'oval', 'color': 'cyan', 'originalDatatype': 'None'})
    apply(getMolePath_34.addOutputPort, (), {'name': 'mol_path', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
    code = """def doit(self, mol, mol_paths):
    if len(mol_paths) == 1:
        self.outputData(mol_path=mol_paths[0])

    for i in mol_paths:
        if os.path.basename(i) == mol:
            fn = i + os.sep + mol
            pdbqt = fn + '''.pdbqt'''
            pqr = fn + '''.pqr'''
            pdb = fn + '''.pdb'''
            
            if os.path.exists(pdbqt):
                self.outputData(mol_path=pdbqt)
            elif os.path.exists(pqr):
                self.outputData(mol_path=pqr)
            elif os.path.exists(pdb):
                self.outputData(mol_path=pdb)
                
    	pass
## to ouput data on port mol_path use


















"""
    getMolePath_34.configure(function=code)
    apply(getMolePath_34.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
    from Pmv.VisionInterface.PmvNodes import PmvNode
    Pmv_35 = PmvNode(vf=masterNet.editor.vf, constrkw={'vf': 'masterNet.editor.vf'}, name='Pmv', library=pmvlib)
    LoadMolecule_31.macroNetwork.addNode(Pmv_35,28,119)
    Pmv_35.inputPortByName['cmdName'].widget.set(r"readMolecule", run=False)
    Pmv_35.inputPortByName['molecules'].widget.set(r"", run=False)
    apply(Pmv_35.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
    from Pmv.VisionInterface.PmvNodes import PmvRunCommand
    readMolecule_36 = PmvRunCommand(functionOrString='Run_Command', command=masterNet.editor.vf.readMolecule, namedArgs={'parser': None}, posArgsNames=['filename'], constrkw={'functionOrString': "'Run_Command'", 'command': 'masterNet.editor.vf.readMolecule', 'namedArgs': {'parser': None}, 'posArgsNames': ['filename']}, name='readMolecule', library=pmvlib)
    LoadMolecule_31.macroNetwork.addNode(readMolecule_36,112,221)
    apply(readMolecule_36.inputPortByName['filename'].configure, (), {'datatype': 'string', 'defaultValue': None, 'originalDatatype': 'None'})
    apply(readMolecule_36.inputPortByName['parser'].configure, (), {'defaultValue': None})
    apply(readMolecule_36.configure, (), {'specialPortsVisible': True})
    readMolecule_36.inputPortByName['importString'].widget.set(r"", run=False)
    apply(readMolecule_36.configure, (), {'specialPortsVisible': True, 'paramPanelImmediate': 1})
    from Pmv.VisionInterface.PmvNodes import PmvNode
    Pmv_37 = PmvNode(vf=masterNet.editor.vf, constrkw={'vf': 'masterNet.editor.vf'}, name='Pmv', library=pmvlib)
    LoadMolecule_31.macroNetwork.addNode(Pmv_37,365,85)
    Pmv_37.inputPortByName['cmdName'].widget.set(r"deleteAllMolecules", run=False)
    Pmv_37.inputPortByName['molecules'].widget.set(r"", run=False)
    apply(Pmv_37.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
    from Pmv.VisionInterface.PmvNodes import PmvRunCommand
    deleteAllMolecules_38 = PmvRunCommand(functionOrString='Run_Command', command=masterNet.editor.vf.deleteAllMolecules, constrkw={'functionOrString': "'Run_Command'", 'command': 'masterNet.editor.vf.deleteAllMolecules'}, name='deleteAllMolecules', library=pmvlib)
    LoadMolecule_31.macroNetwork.addNode(deleteAllMolecules_38,382,153)
    deleteAllMolecules_38.inputPortByName['importString'].widget.set(r"", run=False)
    apply(deleteAllMolecules_38.configure, (), {'paramPanelImmediate': 1})
    from Pmv.VisionInterface.PmvNodes import PmvNode
    Pmv_39 = PmvNode(vf=masterNet.editor.vf, constrkw={'vf': 'masterNet.editor.vf'}, name='Pmv', library=pmvlib)
    LoadMolecule_31.macroNetwork.addNode(Pmv_39,77,272)
    Pmv_39.inputPortByName['cmdName'].widget.set(r"computeMSMS", run=False)
    Pmv_39.inputPortByName['molecules'].widget.set(r"", run=False)
    apply(Pmv_39.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
    from Pmv.VisionInterface.PmvNodes import PmvRunCommand
    computeMSMS_40 = PmvRunCommand(functionOrString='Run_Command', command=masterNet.editor.vf.computeMSMS, namedArgs={'hdensity': 6.0, 'hdset': 'None', 'surfName': 'MSMS-MOL', 'density': 3.0, 'perMol': True, 'noHetatm': False, 'display': True, 'pRadius': 1.5}, posArgsNames=['nodes'], constrkw={'functionOrString': "'Run_Command'", 'command': 'masterNet.editor.vf.computeMSMS', 'namedArgs': {'hdensity': 6.0, 'hdset': 'None', 'surfName': 'MSMS-MOL', 'density': 3.0, 'perMol': True, 'noHetatm': False, 'display': True, 'pRadius': 1.5}, 'posArgsNames': ['nodes']}, name='computeMSMS', library=pmvlib)
    LoadMolecule_31.macroNetwork.addNode(computeMSMS_40,319,384)
    apply(computeMSMS_40.inputPortByName['nodes'].configure, (), {'datatype': 'string', 'defaultValue': None, 'originalDatatype': 'None'})
    apply(computeMSMS_40.inputPortByName['hdensity'].configure, (), {'defaultValue': None})
    apply(computeMSMS_40.inputPortByName['hdset'].configure, (), {'defaultValue': None})
    apply(computeMSMS_40.inputPortByName['surfName'].configure, (), {'defaultValue': None})
    apply(computeMSMS_40.inputPortByName['density'].configure, (), {'defaultValue': None})
    apply(computeMSMS_40.inputPortByName['perMol'].configure, (), {'defaultValue': None})
    apply(computeMSMS_40.inputPortByName['noHetatm'].configure, (), {'defaultValue': None})
    apply(computeMSMS_40.inputPortByName['display'].configure, (), {'defaultValue': None})
    apply(computeMSMS_40.inputPortByName['pRadius'].configure, (), {'defaultValue': None})
    apply(computeMSMS_40.configure, (), {'specialPortsVisible': True})
    computeMSMS_40.inputPortByName['importString'].widget.set(r"", run=False)
    computeMSMS_40.inputPortByName['hdensity'].widget.set(6.0, run=False)
    computeMSMS_40.inputPortByName['hdset'].widget.set(r"None", run=False)
    computeMSMS_40.inputPortByName['surfName'].widget.set(r"MSMS-MOL", run=False)
    computeMSMS_40.inputPortByName['density'].widget.set(3.0, run=False)
    computeMSMS_40.inputPortByName['perMol'].widget.set(1, run=False)
    computeMSMS_40.inputPortByName['noHetatm'].widget.set(0, run=False)
    computeMSMS_40.inputPortByName['display'].widget.set(1, run=False)
    computeMSMS_40.inputPortByName['pRadius'].widget.set(1.5, run=False)
    apply(computeMSMS_40.configure, (), {'specialPortsVisible': True, 'paramPanelImmediate': 1})

    ## saving connections for network LoadMolecule ##
    LoadMolecule_31.macroNetwork.freeze()
    input_Ports_32 = LoadMolecule_31.macroNetwork.ipNode
    if input_Ports_32 is not None and getMolePath_34 is not None:
        try:
            LoadMolecule_31.macroNetwork.connectNodes(
                input_Ports_32, getMolePath_34, "new", "mol", blocking=True
                , splitratio=[0.24980279662847732, 0.22054773831723101])
        except:
            print "WARNING: failed to restore connection between input_Ports_32 and getMolePath_34 in network LoadMolecule_31.macroNetwork"
    if input_Ports_32 is not None and getMolePath_34 is not None:
        try:
            LoadMolecule_31.macroNetwork.connectNodes(
                input_Ports_32, getMolePath_34, "new", "mol_paths", blocking=True
                , splitratio=[0.60958416690230111, 0.22486163260138911])
        except:
            print "WARNING: failed to restore connection between input_Ports_32 and getMolePath_34 in network LoadMolecule_31.macroNetwork"
    if Pmv_35 is not None and readMolecule_36 is not None:
        try:
            LoadMolecule_31.macroNetwork.connectNodes(
                Pmv_35, readMolecule_36, "cmd", "command", blocking=True
                , splitratio=[0.69648176561605402, 0.58749861410425019])
        except:
            print "WARNING: failed to restore connection between Pmv_35 and readMolecule_36 in network LoadMolecule_31.macroNetwork"
    if getMolePath_34 is not None and readMolecule_36 is not None:
        try:
            LoadMolecule_31.macroNetwork.connectNodes(
                getMolePath_34, readMolecule_36, "mol_path", "filename", blocking=True
                , splitratio=[0.0, 0.27994494700716432])
        except:
            print "WARNING: failed to restore connection between getMolePath_34 and readMolecule_36 in network LoadMolecule_31.macroNetwork"
    if Pmv_37 is not None and deleteAllMolecules_38 is not None:
        try:
            LoadMolecule_31.macroNetwork.connectNodes(
                Pmv_37, deleteAllMolecules_38, "cmd", "command", blocking=True
                , splitratio=[0.47295098765011379, 0.62794740523785708])
        except:
            print "WARNING: failed to restore connection between Pmv_37 and deleteAllMolecules_38 in network LoadMolecule_31.macroNetwork"
    if deleteAllMolecules_38 is not None and readMolecule_36 is not None:
        try:
            LoadMolecule_31.macroNetwork.connectNodes(
                deleteAllMolecules_38, readMolecule_36, "result", "parser", blocking=True
                , splitratio=[0.27033886000889895, 0.20639273480186354])
        except:
            print "WARNING: failed to restore connection between deleteAllMolecules_38 and readMolecule_36 in network LoadMolecule_31.macroNetwork"
    if Pmv_39 is not None and computeMSMS_40 is not None:
        try:
            LoadMolecule_31.macroNetwork.connectNodes(
                Pmv_39, computeMSMS_40, "cmd", "command", blocking=True
                , splitratio=[0.66433995763273601, 0.54329119167320339])
        except:
            print "WARNING: failed to restore connection between Pmv_39 and computeMSMS_40 in network LoadMolecule_31.macroNetwork"
    if readMolecule_36 is not None and computeMSMS_40 is not None:
        try:
            LoadMolecule_31.macroNetwork.specialConnectNodes(
                readMolecule_36, computeMSMS_40, "trigger", "runNode", blocking=True
                , splitratio=[0.64725691018348408, 0.5514758081666683])
        except:
            print "WARNING: failed to restore connection between readMolecule_36 and computeMSMS_40 in network LoadMolecule_31.macroNetwork"
    output_Ports_33 = LoadMolecule_31.macroNetwork.opNode
    if getMolePath_34 is not None and output_Ports_33 is not None:
        try:
            LoadMolecule_31.macroNetwork.connectNodes(
                getMolePath_34, output_Ports_33, "mol_path", "new", blocking=True
                , splitratio=[0.5282594356295357, 0.20903895812748927])
        except:
            print "WARNING: failed to restore connection between getMolePath_34 and output_Ports_33 in network LoadMolecule_31.macroNetwork"
    if input_Ports_32 is not None and computeMSMS_40 is not None:
        try:
            LoadMolecule_31.macroNetwork.connectNodes(
                input_Ports_32, computeMSMS_40, "getMolePath_mol", "nodes", blocking=True
                , splitratio=[0.38633655118780108, 0.68223326575013044])
        except:
            print "WARNING: failed to restore connection between input_Ports_32 and computeMSMS_40 in network LoadMolecule_31.macroNetwork"
    LoadMolecule_31.macroNetwork.unfreeze()

    ## modifying MacroInputNode dynamic ports
    input_Ports_32.outputPorts[1].configure(name='getMolePath_mol')
    input_Ports_32.outputPorts[2].configure(name='getMolePath_mol_paths')

    ## modifying MacroOutputNode dynamic ports
    output_Ports_33.inputPorts[1].configure(singleConnection='auto')
    output_Ports_33.inputPorts[1].configure(name='getMolePath_mol_path')
    LoadMolecule_31.inputPorts[0].configure(name='getMolePath_mol')
    LoadMolecule_31.inputPorts[0].configure(datatype='string')
    LoadMolecule_31.inputPorts[1].configure(name='getMolePath_mol_paths')
    LoadMolecule_31.inputPorts[1].configure(datatype='list')
    ## configure MacroNode input ports
    LoadMolecule_31.outputPorts[0].configure(name='getMolePath_mol_path')
    LoadMolecule_31.outputPorts[0].configure(datatype='string')
    ## configure MacroNode output ports
    LoadMolecule_31.shrink()
    apply(LoadMolecule_31.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
except:
    print "WARNING: failed to restore MacroNode named LoadMolecule in network masterNet"
    print_exc()
    LoadMolecule_31=None

try:
    ## saving node GetLigands ##
    from Vision.StandardNodes import Generic
    GetLigands_41 = Generic(constrkw={}, name='GetLigands', library=stdlib)
    masterNet.addNode(GetLigands_41,332,135)
    apply(GetLigands_41.addInputPort, (), {'singleConnection': True, 'name': 'rps', 'cast': True, 'datatype': 'list', 'defaultValue': None, 'required': True, 'height': 12, 'width': 12, 'shape': 'oval', 'color': 'cyan', 'originalDatatype': 'None'})
    apply(GetLigands_41.addInputPort, (), {'singleConnection': True, 'name': 'r', 'cast': True, 'datatype': 'string', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white', 'originalDatatype': 'None'})
    apply(GetLigands_41.addOutputPort, (), {'name': 'ligands', 'datatype': 'list', 'height': 12, 'width': 12, 'shape': 'oval', 'color': 'cyan'})
    code = """def doit(self, rps, r):
        import glob
        
        ligandlist = []

        try:
            for i in rps:
                ld = os.path.basename(i)

                if ld == r:
                    liganddir = i
                    break

            lf = liganddir + os.sep + '''summarize_results.txt'''

            f = open(lf)
            f.readline()

            for i in f.readlines():
                ligand = os.path.basename(str(i).split(''',''')[0])
                ligandlist.append(ligand)
                    
            f.close()
        except:
            receptor_path = rps[0]
            d = os.path.dirname(receptor_path)
            rn = os.path.basename(receptor_path)
            cwd = os.getcwd()
            os.chdir(d)
            pdbqts = glob.glob("*.pdbqt")
            os.chdir(cwd)

            for i in pdbqts:
                if i != rn:
                    ligand = i.split('''.''')[0]
                    break
                
            os.chdir(cwd)
            ligandlist.append(ligand)

        
	pass
## to ouput data on port ligands use
        self.outputData(ligands=ligandlist)








































"""
    GetLigands_41.configure(function=code)
    apply(GetLigands_41.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
except:
    print "WARNING: failed to restore Generic named GetLigands in network masterNet"
    print_exc()
    GetLigands_41=None

try:
    ## saving node LigandList ##
    from Vision.StandardNodes import ScrolledListNE
    LigandList_42 = ScrolledListNE(constrkw={}, name='LigandList', library=stdlib)
    masterNet.addNode(LigandList_42,332,190)
    apply(LigandList_42.inputPortByName['selection'].widget.configure, (), {'choices': ['diversity0004', 'diversity0005', 'diversity0003', 'diversity0001', 'diversity0002', 'diversity0006']})
    LigandList_42.inputPortByName['selection'].widget.set(r"diversity0003", run=False)
    code = """def doit(self, valueList, nameList, selection):
    widget = self.inputPorts[2].widget

    if self.firstRun is True:
        seleciton = None
        self.firstRun = False

    # do we run the first time, and have been restored from a network? (then
    # we have both valueList and selection specified)
    if valueList and selection and self.firstRun is True:
        self.firstRun = False
        self.objectList = valueList
        self.nameList = nameList
        data = self.getData(selection, nameList)
        if data is not None:
            self.outputData(selection=data)
        return

    # only rebuild widget if we receive a new valueList
    if self.inputPorts[0].hasNewValidData() or self.inputPorts[1].hasNewValidData():
        if valueList != self.objectList or self.nameList != nameList:
            self.objectList = valueList
            self.nameList = nameList
            if nameList:
                vList = nameList
            else:
                vList = []
                for data in valueList:
                    if type(data) == types.StringType:
                        vList.append(data)
                    else:
                        vList.append(repr(data))
            if widget is not None:
                widget.setlist(vList)
                widget.configure(choices=vList)
                widget.widget.setentry('''''')
            return

    if selection:
        data = self.getData(selection, nameList)
        if data is not None:
            self.outputData(selection=data)

"""
    LigandList_42.configure(function=code)
    apply(LigandList_42.configure, (), {'paramPanelImmediate': 1})
except:
    print "WARNING: failed to restore ScrolledListNE named LigandList in network masterNet"
    print_exc()
    LigandList_42=None

try:
    ## saving node showConformations ##
    from NetworkEditor.macros import MacroNode
    showConformations_43 = MacroNode(name='showConformations')
    masterNet.addNode(showConformations_43, 445, 605)
    output_Ports_45 = showConformations_43.macroNetwork.opNode
    apply(output_Ports_45.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
    output_Ports_45.move(216, 474)
    from Vision.StandardNodes import Eval
    GetDLG_46 = Eval(constrkw={}, name='GetDLG', library=stdlib)
    showConformations_43.macroNetwork.addNode(GetDLG_46,279,87)
    apply(GetDLG_46.inputPortByName['in1'].configure, (), {'datatype': 'string', 'defaultValue': None, 'required': True, 'name': 'r', 'originalDatatype': 'None'})
    apply(GetDLG_46.addInputPort, (), {'singleConnection': True, 'name': 'l', 'cast': True, 'datatype': 'string', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white', 'originalDatatype': 'None'})
    GetDLG_46.inputPortByName['command'].widget.set(r"os.path.dirname(r)+os.sep+l+os.sep+l+'.dlg'", run=False)
    GetDLG_46.inputPortByName['importString'].widget.set(r"", run=False)
    code = """def doit(self, command, importString, r, l):
        import glob

        d = os.path.dirname(r)
        cwd = os.getcwd()
        os.chdir(d)
        dlg = glob.glob('''*.dlg''')
        os.chdir(cwd)

        if len(dlg) == 1:
            gdlg = os.path.join(d, dlg[0])
            self.outputData(result=gdlg)
        else:
            gdlg = os.path.dirname(r)+os.sep+l+os.sep+l+'''.dlg'''
            self.outputData(result=gdlg)










"""
    GetDLG_46.configure(function=code)
    apply(GetDLG_46.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
    from Pmv.VisionInterface.PmvNodes import PmvNode
    Pmv_47 = PmvNode(vf=masterNet.editor.vf, constrkw={'vf': 'masterNet.editor.vf'}, name='Pmv', library=pmvlib)
    showConformations_43.macroNetwork.addNode(Pmv_47,104,190)
    Pmv_47.inputPortByName['cmdName'].widget.set(r"AD41analyze_readDLG", run=False)
    Pmv_47.inputPortByName['molecules'].widget.set(r"", run=False)
    apply(Pmv_47.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
    from Pmv.VisionInterface.PmvNodes import PmvRunCommand
    AD41analyze_readDLG_48 = PmvRunCommand(functionOrString='Run_Command', command=masterNet.editor.vf.AD41analyze_readDLG, namedArgs={'ask': 1, 'addToPrevious': 0}, posArgsNames=['dlgFile'], constrkw={'functionOrString': "'Run_Command'", 'command': 'masterNet.editor.vf.AD41analyze_readDLG', 'namedArgs': {'ask': 1, 'addToPrevious': 0}, 'posArgsNames': ['dlgFile']}, name='AD41analyze_readDLG', library=pmvlib)
    showConformations_43.macroNetwork.addNode(AD41analyze_readDLG_48,195,271)
    apply(AD41analyze_readDLG_48.inputPortByName['dlgFile'].configure, (), {'defaultValue': None})
    apply(AD41analyze_readDLG_48.inputPortByName['ask'].configure, (), {'defaultValue': None})
    apply(AD41analyze_readDLG_48.inputPortByName['addToPrevious'].configure, (), {'defaultValue': None})
    apply(AD41analyze_readDLG_48.configure, (), {'specialPortsVisible': True})
    AD41analyze_readDLG_48.inputPortByName['importString'].widget.set(r"", run=False)
    AD41analyze_readDLG_48.inputPortByName['ask'].widget.set(1, run=False)
    AD41analyze_readDLG_48.inputPortByName['addToPrevious'].widget.set(0, run=False)
    apply(AD41analyze_readDLG_48.configure, (), {'specialPortsVisible': True, 'paramPanelImmediate': 1})
    from Pmv.VisionInterface.PmvNodes import PmvNode
    Pmv_49 = PmvNode(vf=masterNet.editor.vf, constrkw={'vf': 'masterNet.editor.vf'}, name='Pmv', library=pmvlib)
    showConformations_43.macroNetwork.addNode(Pmv_49,106,322)
    apply(Pmv_49.configure, (), {'specialPortsVisible': True})
    Pmv_49.inputPortByName['cmdName'].widget.set(r"AD41analyze_showStates", run=False)
    Pmv_49.inputPortByName['molecules'].widget.set(r"", run=False)
    apply(Pmv_49.configure, (), {'specialPortsVisible': True, 'paramPanelImmediate': 1, 'expanded': False})
    from Pmv.VisionInterface.PmvNodes import PmvRunCommand
    AD41analyze_showStates_50 = PmvRunCommand(functionOrString='Run_Command', command=masterNet.editor.vf.AD41analyze_showStates, namedArgs={'log': 1}, posArgsNames=['mol'], constrkw={'functionOrString': "'Run_Command'", 'command': 'masterNet.editor.vf.AD41analyze_showStates', 'namedArgs': {'log': 1}, 'posArgsNames': ['mol']}, name='AD41analyze_showStates', library=pmvlib)
    showConformations_43.macroNetwork.addNode(AD41analyze_showStates_50,331,400)
    apply(AD41analyze_showStates_50.inputPortByName['mol'].configure, (), {'datatype': 'string', 'defaultValue': None, 'originalDatatype': 'None'})
    apply(AD41analyze_showStates_50.inputPortByName['log'].configure, (), {'defaultValue': None})
    AD41analyze_showStates_50.inputPortByName['importString'].widget.set(r"", run=False)
    AD41analyze_showStates_50.inputPortByName['log'].widget.set(1, run=False)
    apply(AD41analyze_showStates_50.configure, (), {'paramPanelImmediate': 1})
    from Vision.StandardNodes import Generic
    GetMolList_51 = Generic(constrkw={}, name='GetMolList', library=stdlib)
    showConformations_43.macroNetwork.addNode(GetMolList_51,475,238)
    apply(GetMolList_51.addInputPort, (), {'singleConnection': True, 'name': 'Pmv', 'cast': True, 'datatype': 'PmvInstance', 'defaultValue': None, 'required': True, 'height': 12, 'width': 12, 'shape': 'circle', 'color': '#7A7AFF', 'originalDatatype': 'None'})
    apply(GetMolList_51.addInputPort, (), {'singleConnection': True, 'name': 'in1', 'cast': True, 'datatype': 'string', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white', 'originalDatatype': 'None'})
    apply(GetMolList_51.addInputPort, (), {'singleConnection': True, 'name': 'in2', 'cast': True, 'datatype': 'string', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white', 'originalDatatype': 'None'})
    apply(GetMolList_51.addOutputPort, (), {'name': 'out0', 'datatype': 'None', 'height': 8, 'width': 12, 'shape': 'diamond', 'color': 'white'})
    code = """def doit(self, Pmv, in1, in2):
        assert Pmv is not None
        receptor = os.path.basename(in1)
        receptor = receptor.split('''.''')[0]

        all = map(lambda x: x.name, Pmv.Mols)
         
        mols = list()

        for i in all:
            if i != in2 and i != receptor:
                mols.append(i)

        for i in Pmv.Mols:
            if i.name != in2 and i.name != receptor:
                i.spw.Close_cb()

        Pmv.showMolecules(mols, negate=True, log=0)

	pass
        self.outputData(out0=mols)







































"""
    GetMolList_51.configure(function=code)
    apply(GetMolList_51.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
    from Pmv.VisionInterface.PmvNodes import PmvNode
    Pmv_52 = PmvNode(vf=masterNet.editor.vf, constrkw={'vf': 'masterNet.editor.vf'}, name='Pmv', library=pmvlib)
    showConformations_43.macroNetwork.addNode(Pmv_52,475,22)
    apply(Pmv_52.inputPortByName['cmdName'].configure, (), {'defaultValue': None})
    apply(Pmv_52.inputPortByName['molecules'].configure, (), {'defaultValue': None})
    Pmv_52.inputPortByName['cmdName'].widget.set(r"", run=False)
    Pmv_52.inputPortByName['molecules'].widget.set(r"", run=False)
    apply(Pmv_52.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
    from Vision.StandardNodes import Iterate
    iterate_53 = Iterate(constrkw={}, name='iterate', library=stdlib)
    showConformations_43.macroNetwork.addNode(iterate_53,475,294)
    iterate_53.inputPortByName['stopOnFailure'].widget.set(0, run=False)
    apply(iterate_53.configure, (), {'paramPanelImmediate': 1})
    from Pmv.VisionInterface.PmvNodes import PmvNode
    Pmv_54 = PmvNode(vf=masterNet.editor.vf, constrkw={'vf': 'masterNet.editor.vf'}, name='Pmv', library=pmvlib)
    showConformations_43.macroNetwork.addNode(Pmv_54,723,308)
    apply(Pmv_54.inputPortByName['molecules'].configure, (), {'defaultValue': None})
    Pmv_54.inputPortByName['cmdName'].widget.set(r"deleteMol", run=False)
    apply(Pmv_54.inputPortByName['molecules'].widget.configure, (), {'initialValue': ''})
    Pmv_54.inputPortByName['molecules'].widget.set(r"", run=False)
    apply(Pmv_54.configure, (), {'paramPanelImmediate': 1})
    from Pmv.VisionInterface.PmvNodes import PmvRunCommand
    deleteMol_55 = PmvRunCommand(functionOrString='Run_Command', command=masterNet.editor.vf.deleteMol, posArgsNames=['nodes'], constrkw={'functionOrString': "'Run_Command'", 'command': 'masterNet.editor.vf.deleteMol', 'posArgsNames': ['nodes']}, name='deleteMol', library=pmvlib)
    showConformations_43.macroNetwork.addNode(deleteMol_55,740,519)
    apply(deleteMol_55.inputPortByName['nodes'].configure, (), {'datatype': 'string', 'defaultValue': None, 'originalDatatype': 'None'})
    deleteMol_55.inputPortByName['importString'].widget.set(r"", run=False)
    apply(deleteMol_55.configure, (), {'paramPanelImmediate': 1})

    ## saving connections for network showConformations ##
    showConformations_43.macroNetwork.freeze()
    input_Ports_44 = showConformations_43.macroNetwork.ipNode
    if input_Ports_44 is not None and GetDLG_46 is not None:
        try:
            showConformations_43.macroNetwork.connectNodes(
                input_Ports_44, GetDLG_46, "new", "r", blocking=True
                , splitratio=[0.26234506821098308, 0.6656624353667191])
        except:
            print "WARNING: failed to restore connection between input_Ports_44 and GetDLG_46 in network showConformations_43.macroNetwork"
    if input_Ports_44 is not None and GetDLG_46 is not None:
        try:
            showConformations_43.macroNetwork.connectNodes(
                input_Ports_44, GetDLG_46, "new", "l", blocking=True
                , splitratio=[0.53453878173699376, 0.4159357464430653])
        except:
            print "WARNING: failed to restore connection between input_Ports_44 and GetDLG_46 in network showConformations_43.macroNetwork"
    if Pmv_47 is not None and AD41analyze_readDLG_48 is not None:
        try:
            showConformations_43.macroNetwork.connectNodes(
                Pmv_47, AD41analyze_readDLG_48, "cmd", "command", blocking=True
                , splitratio=[0.57491641052651632, 0.3442523394673046])
        except:
            print "WARNING: failed to restore connection between Pmv_47 and AD41analyze_readDLG_48 in network showConformations_43.macroNetwork"
    if GetDLG_46 is not None and AD41analyze_readDLG_48 is not None:
        try:
            showConformations_43.macroNetwork.connectNodes(
                GetDLG_46, AD41analyze_readDLG_48, "result", "dlgFile", blocking=True
                , splitratio=[0.47662859017673675, 0.50339935651828926])
        except:
            print "WARNING: failed to restore connection between GetDLG_46 and AD41analyze_readDLG_48 in network showConformations_43.macroNetwork"
    if Pmv_49 is not None and AD41analyze_showStates_50 is not None:
        try:
            showConformations_43.macroNetwork.connectNodes(
                Pmv_49, AD41analyze_showStates_50, "cmd", "command", blocking=True
                , splitratio=[0.64967078868628358, 0.64428057462546762])
        except:
            print "WARNING: failed to restore connection between Pmv_49 and AD41analyze_showStates_50 in network showConformations_43.macroNetwork"
    if input_Ports_44 is not None and AD41analyze_showStates_50 is not None:
        try:
            showConformations_43.macroNetwork.connectNodes(
                input_Ports_44, AD41analyze_showStates_50, "GetDLG_l", "mol", blocking=True
                , splitratio=[0.59773853174410363, 0.54712794118729791])
        except:
            print "WARNING: failed to restore connection between input_Ports_44 and AD41analyze_showStates_50 in network showConformations_43.macroNetwork"
    if AD41analyze_readDLG_48 is not None and Pmv_49 is not None:
        try:
            showConformations_43.macroNetwork.specialConnectNodes(
                AD41analyze_readDLG_48, Pmv_49, "trigger", "runNode", blocking=True
                , splitratio=[0.65295701563963271, 0.25994567324342494])
        except:
            print "WARNING: failed to restore connection between AD41analyze_readDLG_48 and Pmv_49 in network showConformations_43.macroNetwork"
    if Pmv_52 is not None and GetMolList_51 is not None:
        try:
            showConformations_43.macroNetwork.connectNodes(
                Pmv_52, GetMolList_51, "PMV", "Pmv", blocking=True
                , splitratio=[0.22281755983671137, 0.33186887241855467])
        except:
            print "WARNING: failed to restore connection between Pmv_52 and GetMolList_51 in network showConformations_43.macroNetwork"
    if input_Ports_44 is not None and GetMolList_51 is not None:
        try:
            showConformations_43.macroNetwork.connectNodes(
                input_Ports_44, GetMolList_51, "GetDLG_r", "in1", blocking=True
                , splitratio=[0.36237916545154802, 0.31658155256651488])
        except:
            print "WARNING: failed to restore connection between input_Ports_44 and GetMolList_51 in network showConformations_43.macroNetwork"
    if input_Ports_44 is not None and GetMolList_51 is not None:
        try:
            showConformations_43.macroNetwork.connectNodes(
                input_Ports_44, GetMolList_51, "GetDLG_l", "in2", blocking=True
                , splitratio=[0.255800713950466, 0.58101478394391592])
        except:
            print "WARNING: failed to restore connection between input_Ports_44 and GetMolList_51 in network showConformations_43.macroNetwork"
    if GetMolList_51 is not None and iterate_53 is not None:
        try:
            showConformations_43.macroNetwork.connectNodes(
                GetMolList_51, iterate_53, "out0", "listToLoopOver", blocking=True
                , splitratio=[0.44949206687942495, 0.36654806863201056])
        except:
            print "WARNING: failed to restore connection between GetMolList_51 and iterate_53 in network showConformations_43.macroNetwork"
    if Pmv_54 is not None and deleteMol_55 is not None:
        try:
            showConformations_43.macroNetwork.connectNodes(
                Pmv_54, deleteMol_55, "cmd", "command", blocking=True
                , splitratio=[0.4998784570684916, 0.65389681202102112])
        except:
            print "WARNING: failed to restore connection between Pmv_54 and deleteMol_55 in network showConformations_43.macroNetwork"
    if iterate_53 is not None and deleteMol_55 is not None:
        try:
            showConformations_43.macroNetwork.connectNodes(
                iterate_53, deleteMol_55, "oneItem", "nodes", blocking=True
                , splitratio=[0.44123508306032516, 0.65896171775828805])
        except:
            print "WARNING: failed to restore connection between iterate_53 and deleteMol_55 in network showConformations_43.macroNetwork"
    showConformations_43.macroNetwork.unfreeze()

    ## modifying MacroInputNode dynamic ports
    input_Ports_44.outputPorts[1].configure(name='GetDLG_r')
    input_Ports_44.outputPorts[2].configure(name='GetDLG_l')
    showConformations_43.inputPorts[0].configure(name='GetDLG_r')
    showConformations_43.inputPorts[0].configure(datatype='string')
    showConformations_43.inputPorts[1].configure(name='GetDLG_l')
    showConformations_43.inputPorts[1].configure(datatype='string')
    ## configure MacroNode input ports
    ## configure MacroNode output ports
    showConformations_43.shrink()
    apply(showConformations_43.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
except:
    print "WARNING: failed to restore MacroNode named showConformations in network masterNet"
    print_exc()
    showConformations_43=None

#masterNet.run()
masterNet.freeze()

## saving connections for network visualization-0.1.2 ##
if AutoDock_VS_Result_Directory_28 is not None and GetReceptors_29 is not None:
    try:
        masterNet.connectNodes(
            AutoDock_VS_Result_Directory_28, GetReceptors_29, "AbsPath_directory", "dir", blocking=True
            , splitratio=[0.55778921299744577, 0.56280875000248676])
    except:
        print "WARNING: failed to restore connection between AutoDock_VS_Result_Directory_28 and GetReceptors_29 in network masterNet"
if GetReceptors_29 is not None and ReceptorList_30 is not None:
    try:
        masterNet.connectNodes(
            GetReceptors_29, ReceptorList_30, "receptors", "valueList", blocking=True
            , splitratio=[0.49417000742132478, 0.47069046596772096])
    except:
        print "WARNING: failed to restore connection between GetReceptors_29 and ReceptorList_30 in network masterNet"
LoadMolecule_31 = masterNet.nodes[3]
if ReceptorList_30 is not None and LoadMolecule_31 is not None:
    try:
        masterNet.connectNodes(
            ReceptorList_30, LoadMolecule_31, "selection", "getMolePath_mol", blocking=True
            , splitratio=[0.58076619839464139, 0.55084429716865135])
    except:
        print "WARNING: failed to restore connection between ReceptorList_30 and LoadMolecule_31 in network masterNet"
if GetReceptors_29 is not None and LoadMolecule_31 is not None:
    try:
        masterNet.connectNodes(
            GetReceptors_29, LoadMolecule_31, "receptor_paths", "getMolePath_mol_paths", blocking=True
            , splitratio=[0.26226541430302935, 0.64839302256375586])
    except:
        print "WARNING: failed to restore connection between GetReceptors_29 and LoadMolecule_31 in network masterNet"
if GetReceptors_29 is not None and GetLigands_41 is not None:
    try:
        masterNet.connectNodes(
            GetReceptors_29, GetLigands_41, "receptor_paths", "rps", blocking=True
            , splitratio=[0.65123470982731246, 0.32544270134226649])
    except:
        print "WARNING: failed to restore connection between GetReceptors_29 and GetLigands_41 in network masterNet"
if ReceptorList_30 is not None and GetLigands_41 is not None:
    try:
        masterNet.connectNodes(
            ReceptorList_30, GetLigands_41, "selection", "r", blocking=True
            , splitratio=[0.42878253007466194, 0.72341691404242114])
    except:
        print "WARNING: failed to restore connection between ReceptorList_30 and GetLigands_41 in network masterNet"
if GetLigands_41 is not None and LigandList_42 is not None:
    try:
        masterNet.connectNodes(
            GetLigands_41, LigandList_42, "ligands", "valueList", blocking=True
            , splitratio=[0.63046613222846459, 0.43881484615970567])
    except:
        print "WARNING: failed to restore connection between GetLigands_41 and LigandList_42 in network masterNet"
showConformations_43 = masterNet.nodes[6]
if LoadMolecule_31 is not None and showConformations_43 is not None:
    try:
        masterNet.connectNodes(
            LoadMolecule_31, showConformations_43, "getMolePath_mol_path", "GetDLG_r", blocking=True
            , splitratio=[0.33003249460940892, 0.589279306283232])
    except:
        print "WARNING: failed to restore connection between LoadMolecule_31 and showConformations_43 in network masterNet"
if LigandList_42 is not None and showConformations_43 is not None:
    try:
        masterNet.connectNodes(
            LigandList_42, showConformations_43, "selection", "GetDLG_l", blocking=True
            , splitratio=[0.53554392069653656, 0.40654195768645573])
    except:
        print "WARNING: failed to restore connection between LigandList_42 and showConformations_43 in network masterNet"
masterNet.runOnNewData.value = True

if __name__=='__main__':
    from sys import argv
    lNodePortValues = []
    if (len(argv) > 1) and argv[1].startswith('-'):
        lArgIndex = 2
    else:
        lArgIndex = 1
    while lArgIndex < len(argv) and argv[lArgIndex][-3:]!='.py':
        lNodePortValues.append(argv[lArgIndex])
        lArgIndex += 1
    masterNet.setNodePortValues(lNodePortValues)
    if '--help' in argv or '-h' in argv: # show help
        masterNet.helpForNetworkAsApplication()
    elif '-w' in argv: # run without Vision and exit
         # create communicator
        from NetworkEditor.net import Communicator
        masterNet.communicator = Communicator(masterNet)
        print 'Communicator listening on port:', masterNet.communicator.port

        import socket
        f = open(argv[0]+'.sock', 'w')
        f.write("%s %i"%(socket.gethostbyname(socket.gethostname()),
                         masterNet.communicator.port))
        f.close()

        masterNet.run()

    else: # stand alone application while vision is hidden
        if '-e' in argv: # run and exit
            masterNet.run()
        elif '-r' in argv or len(masterNet.userPanels) == 0: # no user panel => run
            masterNet.run()
            mainLoopVisionToRunNetworkAsApplication(masterNet.editor)
        else: # user panel
            mainLoopVisionToRunNetworkAsApplication(masterNet.editor)




#!/bin/ksh ~/.mgltools/pythonsh
########################################################################
#
#    Vision Network - Python source code - file generated by vision
#    Thursday 24 February 2011 03:10:56 
#    
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Daniel Stoffler, Michel Sanner and TSRI
#   
# revision: Guillaume Vareille
#  
#########################################################################
#
# $Header: /opt/cvs/CADD/workflows/docking/PrepareReceptor_0.1_net.py,v 1.1 2011/04/15 16:16:49 nadya Exp $
#
# $Id: PrepareReceptor_0.1_net.py,v 1.1 2011/04/15 16:16:49 nadya Exp $
#


if __name__=='__main__':
    from sys import argv
    if '--help' in argv or '-h' in argv or '-w' in argv: # run without Vision
        withoutVision = True
        from Vision.VPE import NoGuiExec
        ed = NoGuiExec()
        from NetworkEditor.net import Network
        import os
        masterNet = Network("process-"+str(os.getpid()))
        ed.addNetwork(masterNet)
    else: # run as a stand alone application while vision is hidden
        withoutVision = False
        from Vision import launchVisionToRunNetworkAsApplication, mainLoopVisionToRunNetworkAsApplication
	if '-noSplash' in argv:
	    splash = False
	else:
	    splash = True
        masterNet = launchVisionToRunNetworkAsApplication(splash=splash)
        import os
        masterNet.filename = os.path.abspath(__file__)
from traceback import print_exc
## loading libraries ##
from AutoDockTools.VisionInterface.Adt import Adt
from WebServices.VisionInterface.WSNodes import wslib
from Vision.StandardNodes import stdlib
try:
    masterNet
except (NameError, AttributeError): # we run the network outside Vision
    from NetworkEditor.net import Network
    masterNet = Network()

masterNet.getEditor().addLibraryInstance(Adt,"AutoDockTools.VisionInterface.Adt", "Adt")

masterNet.getEditor().addLibraryInstance(wslib,"WebServices.VisionInterface.WSNodes", "wslib")

masterNet.getEditor().addLibraryInstance(stdlib,"Vision.StandardNodes", "stdlib")

from WebServices.VisionInterface.WSNodes import addOpalServerAsCategory
try:
    addOpalServerAsCategory("http://ws.nbcr.net/opal2", replace=False)
except:
    pass
try:
    ## saving node PrepareReceptor2 ##
    from Adt.Macro.PrepareReceptor import PrepareReceptor
    PrepareReceptor2_0 = PrepareReceptor(constrkw={}, name='PrepareReceptor2', library=Adt)
    masterNet.addNode(PrepareReceptor2_0,301,206)
    apply(PrepareReceptor2_0.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
    Pdb2pqrWS_3 = PrepareReceptor2_0.macroNetwork.nodes[2]
    Pdb2pqrOpalService_ws_nbcr_net_7 = Pdb2pqrWS_3.macroNetwork.nodes[3]
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['noopt'].widget.set(0, run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['phi'].widget.set(0, run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['psi'].widget.set(0, run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['verbose'].widget.set(1, run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['chain'].widget.set(0, run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['nodebump'].widget.set(0, run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['chi'].widget.set(0, run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['ligand'].widget.set(r"", run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['hbond'].widget.set(0, run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['with_ph'].widget.set(r"", run=False)
    apply(Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['forcefield'].widget.configure, (), {'choices': ('AMBER', 'CHARMM', 'PARSE', 'TYL06')})
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['forcefield'].widget.set(r"AMBER", run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['clean'].widget.set(0, run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['inId'].widget.set(r"", run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['apbs_input'].widget.set(0, run=False)
    apply(Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['ffout'].widget.configure, (), {'choices': ('AMBER', 'CHARMM', 'PARSE', 'TYL06')})
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['ffout'].widget.set(r"", run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['localRun'].widget.set(0, run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['rama'].widget.set(0, run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['execPath'].widget.set(r"", run=False)
    Pdb2pqrOpalService_ws_nbcr_net_7.inputPortByName['assign_only'].widget.set(0, run=False)
    GetURLFromList_8 = Pdb2pqrWS_3.macroNetwork.nodes[4]
    GetURLFromList_8.inputPortByName['ext'].widget.set(r"pqr", run=False)

    ## saving connections for network Pdb2pqrWS ##
    Pdb2pqrWS_3.macroNetwork.freeze()
    Pdb2pqrWS_3.macroNetwork.unfreeze()

    ## modifying MacroInputNode dynamic ports
    input_Ports_4 = Pdb2pqrWS_3.macroNetwork.ipNode
    input_Ports_4.outputPorts[1].configure(name='CheckFileFormat_value')

    ## modifying MacroOutputNode dynamic ports
    output_Ports_5 = Pdb2pqrWS_3.macroNetwork.opNode
    output_Ports_5.inputPorts[1].configure(singleConnection='auto')
    output_Ports_5.inputPorts[2].configure(singleConnection='auto')
    output_Ports_5.inputPorts[1].configure(name='UpdateReceptor_receptor_obj')
    output_Ports_5.inputPorts[2].configure(name='UpdateReceptor_pdb2pqr_result')
    Pdb2pqrWS_3.inputPorts[0].configure(name='CheckFileFormat_value')
    Pdb2pqrWS_3.inputPorts[0].configure(datatype='receptor')
    ## configure MacroNode input ports
    Pdb2pqrWS_3.outputPorts[0].configure(name='UpdateReceptor_receptor_obj')
    Pdb2pqrWS_3.outputPorts[0].configure(datatype='receptor')
    Pdb2pqrWS_3.outputPorts[1].configure(name='UpdateReceptor_pdb2pqr_result')
    Pdb2pqrWS_3.outputPorts[1].configure(datatype='string')
    ## configure MacroNode output ports
    Pdb2pqrWS_3.shrink()
    PrepareReceptorWS_10 = PrepareReceptor2_0.macroNetwork.nodes[3]
    PrepareReceptorOpalService_ws_nbcr_net_14 = PrepareReceptorWS_10.macroNetwork.nodes[3]
    PrepareReceptorOpalService_ws_nbcr_net_14.inputPortByName['o'].widget.set(r"", run=False)
    PrepareReceptorOpalService_ws_nbcr_net_14.inputPortByName['v'].widget.set(0, run=False)
    PrepareReceptorOpalService_ws_nbcr_net_14.inputPortByName['localRun'].widget.set(0, run=False)
    PrepareReceptorOpalService_ws_nbcr_net_14.inputPortByName['execPath'].widget.set(r"", run=False)
    GetURLFromList_15 = PrepareReceptorWS_10.macroNetwork.nodes[4]
    GetURLFromList_15.inputPortByName['ext'].widget.set(r"pdbqt", run=False)
    DownloadToFile_16 = PrepareReceptorWS_10.macroNetwork.nodes[5]
    DownloadToFile_16.inputPortByName['overwrite'].widget.set(1, run=False)

    ## saving connections for network PrepareReceptorWS ##
    PrepareReceptorWS_10.macroNetwork.freeze()
    PrepareReceptorWS_10.macroNetwork.unfreeze()

    ## modifying MacroInputNode dynamic ports
    input_Ports_11 = PrepareReceptorWS_10.macroNetwork.ipNode
    input_Ports_11.outputPorts[1].configure(name='CheckFileFormat_value')
    input_Ports_11.outputPorts[2].configure(name='PrepareReceptorOpalService_ws_nbcr_net_C')

    ## modifying MacroOutputNode dynamic ports
    output_Ports_12 = PrepareReceptorWS_10.macroNetwork.opNode
    output_Ports_12.inputPorts[1].configure(singleConnection='auto')
    output_Ports_12.inputPorts[2].configure(singleConnection='auto')
    output_Ports_12.inputPorts[1].configure(name='UpdateReceptor_receptor_prepared_obj')
    output_Ports_12.inputPorts[2].configure(name='UpdateReceptor_receptor_result')
    PrepareReceptorWS_10.inputPorts[0].configure(name='CheckFileFormat_value')
    PrepareReceptorWS_10.inputPorts[0].configure(datatype='receptor')
    PrepareReceptorWS_10.inputPorts[1].configure(name='PrepareReceptorOpalService_ws_nbcr_net_C')
    PrepareReceptorWS_10.inputPorts[1].configure(datatype='boolean')
    ## configure MacroNode input ports
    PrepareReceptorWS_10.outputPorts[0].configure(name='UpdateReceptor_receptor_prepared_obj')
    PrepareReceptorWS_10.outputPorts[0].configure(datatype='receptor_prepared')
    PrepareReceptorWS_10.outputPorts[1].configure(name='UpdateReceptor_receptor_result')
    PrepareReceptorWS_10.outputPorts[1].configure(datatype='string')
    ## configure MacroNode output ports
    PrepareReceptorWS_10.shrink()

    ## saving connections for network PrepareReceptor2 ##
    PrepareReceptor2_0.macroNetwork.freeze()
    PrepareReceptor2_0.macroNetwork.unfreeze()

    ## modifying MacroInputNode dynamic ports
    input_Ports_1 = PrepareReceptor2_0.macroNetwork.ipNode
    input_Ports_1.outputPorts[1].configure(name='Pdb2pqrWS_CheckFileFormat_value')
    input_Ports_1.outputPorts[2].configure(name='PrepareReceptorWS_PrepareReceptorOpalService_ws_nbcr_net_C')

    ## modifying MacroOutputNode dynamic ports
    output_Ports_2 = PrepareReceptor2_0.macroNetwork.opNode
    output_Ports_2.inputPorts[1].configure(singleConnection='auto')
    output_Ports_2.inputPorts[2].configure(singleConnection='auto')
    output_Ports_2.inputPorts[1].configure(name='PrepareReceptorWS_UpdateReceptor_receptor_prepared_obj')
    output_Ports_2.inputPorts[2].configure(name='PrepareReceptorWS_UpdateReceptor_receptor_result')
    PrepareReceptor2_0.inputPorts[0].configure(name='Pdb2pqrWS_CheckFileFormat_value')
    PrepareReceptor2_0.inputPorts[0].configure(datatype='receptor')
    PrepareReceptor2_0.inputPorts[1].configure(name='PrepareReceptorWS_PrepareReceptorOpalService_ws_nbcr_net_C')
    PrepareReceptor2_0.inputPorts[1].configure(datatype='boolean')
    ## configure MacroNode input ports
    PrepareReceptor2_0.outputPorts[0].configure(name='PrepareReceptorWS_UpdateReceptor_receptor_prepared_obj')
    PrepareReceptor2_0.outputPorts[0].configure(datatype='receptor_prepared')
    PrepareReceptor2_0.outputPorts[1].configure(name='PrepareReceptorWS_UpdateReceptor_receptor_result')
    PrepareReceptor2_0.outputPorts[1].configure(datatype='string')
    ## configure MacroNode output ports
    PrepareReceptor2_0.shrink()
    apply(PrepareReceptor2_0.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
except:
    print "WARNING: failed to restore PrepareReceptor named PrepareReceptor2 in network masterNet"
    print_exc()
    PrepareReceptor2_0=None

try:
    ## saving node StructureBrowser ##
    from Adt.Input.StructureBrowser import StructureBrowser
    StructureBrowser_18 = StructureBrowser(constrkw={}, name='StructureBrowser', library=Adt)
    masterNet.addNode(StructureBrowser_18,52,43)
    StructureBrowser_18.inputPortByName['receptor_file'].widget.set(r"PrepareReceptor_0.1_input/2HTY_A.pdb", run=False)
    apply(StructureBrowser_18.configure, (), {'paramPanelImmediate': 1})
except:
    print "WARNING: failed to restore StructureBrowser named StructureBrowser in network masterNet"
    print_exc()
    StructureBrowser_18=None

try:
    ## saving node Preserve charges? ##
    from Vision.StandardNodes import CheckButtonNE
    Preserve_charges__19 = CheckButtonNE(constrkw={}, name='Preserve charges?', library=stdlib)
    masterNet.addNode(Preserve_charges__19,458,43)
    Preserve_charges__19.inputPortByName['button'].widget.set(0, run=False)
    apply(Preserve_charges__19.configure, (), {'paramPanelImmediate': 1})
except:
    print "WARNING: failed to restore CheckButtonNE named Preserve charges? in network masterNet"
    print_exc()
    Preserve_charges__19=None

try:
    ## saving node SaveReceptor ##
    from Vision.StandardNodes import Generic
    SaveReceptor_20 = Generic(constrkw={}, name='SaveReceptor', library=stdlib)
    masterNet.addNode(SaveReceptor_20,424,278)
    apply(SaveReceptor_20.addInputPort, (), {'singleConnection': True, 'name': 'r', 'cast': True, 'datatype': 'string', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white', 'originalDatatype': 'None'})
    apply(SaveReceptor_20.addInputPort, (), {'singleConnection': True, 'name': 'outdir', 'cast': True, 'datatype': 'string', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white', 'originalDatatype': 'None'})
    apply(SaveReceptor_20.addOutputPort, (), {'name': 'outdir', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
    code = """def doit(self, r, outdir):
        outfile = os.path.join(outdir, os.path.basename(r))
        if (r.startswith("http://")):
            import urllib
            opener = urllib.FancyURLopener({})
            in_file = opener.open(r)
            f = open(filename, '''w''')
            f.write(in_file.read())
            f.close()
        else:
            import shutil
            shutil.copy (r, outfile)
        
	pass
## to ouput data on port outdir use
        self.outputData(outdir=outfile)



"""
    SaveReceptor_20.configure(function=code)
    apply(SaveReceptor_20.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
except:
    print "WARNING: failed to restore Generic named SaveReceptor in network masterNet"
    print_exc()
    SaveReceptor_20=None

try:
    ## saving node Output Directory Browser ##
    from Vision.StandardNodes import DirBrowserNE
    Output_Directory_Browser_21 = DirBrowserNE(constrkw={}, name='Output Directory Browser', library=stdlib)
    masterNet.addNode(Output_Directory_Browser_21,638,46)
    Output_Directory_Browser_21.inputPortByName['directory'].widget.set(r"PrepareReceptor_0.1_output", run=False)
    apply(Output_Directory_Browser_21.configure, (), {'paramPanelImmediate': 1})
except:
    print "WARNING: failed to restore DirBrowserNE named Output Directory Browser in network masterNet"
    print_exc()
    Output_Directory_Browser_21=None

#masterNet.run()
masterNet.freeze()

## saving connections for network PrepareReceptor-0.1 ##
if StructureBrowser_18 is not None and PrepareReceptor2_0 is not None:
    try:
        masterNet.connectNodes(
            StructureBrowser_18, PrepareReceptor2_0, "receptor_obj", "Pdb2pqrWS_CheckFileFormat_value", blocking=True
            , splitratio=[0.51287662428234593, 0.74658029742646814])
    except:
        print "WARNING: failed to restore connection between StructureBrowser_18 and PrepareReceptor2_0 in network masterNet"
if Preserve_charges__19 is not None and PrepareReceptor2_0 is not None:
    try:
        masterNet.connectNodes(
            Preserve_charges__19, PrepareReceptor2_0, "value_bool", "PrepareReceptorWS_PrepareReceptorOpalService_ws_nbcr_net_C", blocking=True
            , splitratio=[0.44734707960554609, 0.37373648392115422])
    except:
        print "WARNING: failed to restore connection between Preserve_charges__19 and PrepareReceptor2_0 in network masterNet"
if PrepareReceptor2_0 is not None and SaveReceptor_20 is not None:
    try:
        masterNet.connectNodes(
            PrepareReceptor2_0, SaveReceptor_20, "PrepareReceptorWS_UpdateReceptor_receptor_result", "r", blocking=True
            , splitratio=[0.38815590219305951, 0.71363867512527479])
    except:
        print "WARNING: failed to restore connection between PrepareReceptor2_0 and SaveReceptor_20 in network masterNet"
if Output_Directory_Browser_21 is not None and SaveReceptor_20 is not None:
    try:
        masterNet.connectNodes(
            Output_Directory_Browser_21, SaveReceptor_20, "AbsPath_directory", "outdir", blocking=True
            , splitratio=[0.32372299779158487, 0.59979789316638676])
    except:
        print "WARNING: failed to restore connection between Output_Directory_Browser_21 and SaveReceptor_20 in network masterNet"
masterNet.runOnNewData.value = False

if __name__=='__main__':
    from sys import argv
    lNodePortValues = []
    if (len(argv) > 1) and argv[1].startswith('-'):
        lArgIndex = 2
    else:
        lArgIndex = 1
    while lArgIndex < len(argv) and argv[lArgIndex][-3:]!='.py':
        lNodePortValues.append(argv[lArgIndex])
        lArgIndex += 1
    masterNet.setNodePortValues(lNodePortValues)
    if '--help' in argv or '-h' in argv: # show help
        masterNet.helpForNetworkAsApplication()
    elif '-w' in argv: # run without Vision and exit
         # create communicator
        from NetworkEditor.net import Communicator
        masterNet.communicator = Communicator(masterNet)
        print 'Communicator listening on port:', masterNet.communicator.port

        import socket
        f = open(argv[0]+'.sock', 'w')
        f.write("%s %i"%(socket.gethostbyname(socket.gethostname()),
                         masterNet.communicator.port))
        f.close()

        masterNet.run()

    else: # stand alone application while vision is hidden
        if '-e' in argv: # run and exit
            masterNet.run()
        elif '-r' in argv or len(masterNet.userPanels) == 0: # no user panel => run
            masterNet.run()
            mainLoopVisionToRunNetworkAsApplication(masterNet.editor)
        else: # user panel
            mainLoopVisionToRunNetworkAsApplication(masterNet.editor)




#       
#           AutoDock | Raccoon2
#
#       Copyright 2013, Stefano Forli
#          Molecular Graphics Lab
#  
#     The Scripps Research Institute 
#           _  
#          (,)  T  h e
#         _/
#        (.)    S  c r i p p s
#          \_
#          (,)  R  e s e a r c h
#         ./  
#        ( )    I  n s t i t u t e
#         '
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import inspect
from datetime import datetime

class DebugObj:
    """
    provide basic funcionality of logging printing 
    based on debug level
    
    OPTIONS
        debug = False       : debug messages disabled
              = True        : debug messages printed on screen
              = string      : debug messages saved to filename = string

    dprint()  : debug-level dependent print function
              return the string "function [CALLER:function_caller]> message"

    TODO Add indent to show hierarchy?

    """
    def __init__(self, debug=False):

        self._dbug_spacer = "=====================================\n"
        # is a filename to open
        if type(debug) == type(''):
            bufsize = 0
            debug = open(debug, 'a', bufsize)
            debug.write("\n\n\n\n"+self._dbug_spacer+"Debug file opened on (%s)" % datetime.now())
        # it is a file pointer (nothing to do, keep going...)
        elif str(type(debug)) == "<type 'file'>":
            pass
        self.debug = debug

    def caller(self, level=1):
        #print "CALLER", inspect.stack()[1][3]
        #print "\n\n\nSTACK"
        #for i in inspect.stack():
        #    print i
        #    print "--------------"
        #print "\n++++++++++++++++++++++\n"
        try:
            return inspect.stack()[2+level][3] 
        except:
            return "(unknown)"

    def moduleName(self, level=0):
        """ attempt to print module name"""
        s = inspect.stack()
        #print "\nSTACK"
        #for x in range(len(s)):
        #    print "%d) %s" % (x, s[x])
        module_name = inspect.getmodulename(s[2-level][1])
        return module_name

    def dprint(self, msg, new=False, args=False):
        """this is where the magic happens"""
        if not self.debug: return
        # inspect the stack frame
        curframe = inspect.currentframe()
        calframe = inspect.getouterframes(curframe, 2)
        fname = calframe[1][3]
        if args == True:
            _arg, _, _, _val = inspect.getargvalues(curframe)
            a_v = ",".join(['%s = %s' % (x, _val[x]) for x in _arg])
        else:
            a_v = ""

        # add newline if necessary
        if new == True: 
            nl = '\n\n'
        else:
            nl = ''
        # composing the message
        #msg = "%sDEBUG[%s] %s(%s) [CALLER:%s() module: %s] >> %s" % (nl, datetime.now(), fname, a_v, self.caller(), self.moduleName(), msg)
        msg = "%sDEBUG[%s] %s.%s(%s) [CALLER:%s.%s()] >> %s" % (nl, datetime.now(), self.moduleName(-1), fname, a_v, self.moduleName(), self.caller(), msg)
        if str(type(self.debug)) == "<type 'file'>":
            self.debug.write(msg + '\n')
        else:
            print msg



#       
#           AutoDock | Raccoon2
#
#       Copyright 2013, Stefano Forli
#          Molecular Graphics Lab
#  
#     The Scripps Research Institute 
#           _  
#          (,)  T  h e
#         _/
#        (.)    S  c r i p p s
#          \_
#          (,)  R  e s e a r c h
#         ./  
#        ( )    I  n s t i t u t e
#         '
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import TkTreectrl, os, Tkinter, Pmw
import tkMessageBox as tmb
import tkFileDialog as tfd
import CADD.Raccoon2.HelperFunctionsN3P as hf
import CADD.Raccoon2
import Tkinter as tk
from PIL import Image, ImageTk




class DictTreeCheckSelector:

    def __init__(self, master, history):
        
        self.master = master
        self.history = history
        self.initIcons()

        self.results = []
        self.checkedItems = {}
        self.createTree()

    def initIcons(self):
        """ initialize the icons for the interface"""
        #icon_path = '/entropia/code/latest/MGLToolsPckgs/CADD/Raccoon2/gui/icons'
        icon_path = CADD.Raccoon2.ICONPATH
        f = icon_path + os.sep + 'prj.png'
        self._ICON_prj = ImageTk.PhotoImage(Image.open(f))

        f = icon_path + os.sep + 'exp.png'
        self._ICON_exp = ImageTk.PhotoImage(Image.open(f))
        
        f = icon_path + os.sep + 'vs.png'
        self._ICON_vs = ImageTk.PhotoImage(Image.open(f))



    def createTree(self):
        self.win = Pmw.Dialog(self.master, title='Select downloaded results', buttons=('OK','Cancel'),
                command=self.close)
        #pathlabel = Tkinter.StringVar(value=hf.truncateName(self.RESULTS_LOCATION, 55))

        self.treeObj = TkTreectrl.ScrolledTreectrl(self.win.interior())
        self.treeObj.pack(expand=1,fill='both', padx=5,pady=3)
        self.tree = self.treeObj.treectrl
        #self.itemToName = { TkTreectrl.ROOT : self.history }
        #self.nameToItem = { self.history : TkTreectrl.ROOT }
        self._treeStyles = {}

        # checkbox 
        self.tree.state_define('Checked')
        
        self._checkedIcon = check = \
            Tkinter.PhotoImage(master=self.master,
            data=('R0lGODlhDQANABEAACwAAAAADQANAIEAAAB/f3/f39',
                   '////8CJ4yPNgHtLxYYtNbIbJ146jZ0gzeCIuhQ53N',
                   'JVNpmryZqsYDnemT3BQA7'))
        self._unCheckedIcon = uncheck = \
            Tkinter.PhotoImage(master=self.master,
            data=('R0lGODlhDQANABEAACwAAAAADQANAI',
            'EAAAB/f3/f39////8CIYyPNgHtLxYYtNbIrMZTX+l9WThwZAmSppqGmADHcnRaBQA7'))

        el_image = self.tree.element_create(type='image', image=(
            check, 'Checked', uncheck, ()))
        self.checkboxStyle = styleCheckbox = self.tree.style_create()
        self.tree.style_elements(styleCheckbox, el_image)

        self.tree.style_layout(styleCheckbox, el_image, padx=9, pady=2)
        self.treecol = self.tree.column_create(text='Results')
        self.tree.configure(treecolumn=self.treecol, showbuttons=1) #, expand=1)

        self.checkcol = self.tree.column_create(text='Select', expand=0)

        self._prjIcon = prjIcon = self._ICON_prj
        self._expIcon = expIcon = self._ICON_exp
        #self.tree.column_create(text='results URL', expand=0)
        # style for project
        styleProject = self.tree.style_create()
        pel_image = self.tree.element_create(type=TkTreectrl.IMAGE,
                                    image=(prjIcon, TkTreectrl.OPEN, prjIcon, ''))

        pel_text = self.tree.element_create(type=TkTreectrl.TEXT,  fill=('white', TkTreectrl.SELECTED))
        pel_select = self.tree.element_create(type=TkTreectrl.RECT, showfocus=1,
                                     fill=('blue4', TkTreectrl.SELECTED))
        self.tree.style_elements(styleProject, pel_image, pel_select, pel_text)
        self.tree.style_layout(styleProject, pel_image, pady=1)
        self.tree.style_layout(styleProject, pel_select, union=(pel_text,), padx=1, pady=1, squeeze='')
        self.tree.style_layout(styleProject, pel_text, padx=1, pady=1, ipadx=2,ipady=2) #, squeeze='y')
        self._treeStyles['prj'] = { 'img' : pel_image, 'txt' : pel_text, 'style' : styleProject}

        # style for jobs
        styleJob = self.tree.style_create()
        job_image = self.tree.element_create(type=TkTreectrl.IMAGE,
                                    image=(expIcon, TkTreectrl.OPEN, expIcon, ''))
        self.tree.style_elements(styleJob, job_image, pel_select, pel_text)
        self.tree.style_layout(styleJob, pel_select, union=(pel_text,), padx=1, pady=1, ipadx=1,ipady=1 ) #, squeeze='y')
        self.tree.style_layout(styleJob, job_image, pady=2)
        self._treeStyles['job'] = { 'img' : job_image, 'txt' : pel_text, 'style' : styleJob}

        # style for string cell
        styleString = self.tree.style_create()
        cel_text = self.tree.element_create(type=TkTreectrl.TEXT,  fill=('white', TkTreectrl.SELECTED))
        self.tree.style_elements(styleString, pel_select, cel_text)
        self.tree.style_layout(styleString, cel_text, padx=1, pady=1, squeeze='y')
        self.tree.style_layout(styleString, pel_select, union=(cel_text,), padx=1, pady=1, ipadx=1,ipady=1 )

        self._treeStyles['cell'] = { 'txt' : cel_text, 'style' : styleString}

        # bindings
        self.tree.notify_bind('<Expand-before>', self.expand)
        self.tree.notify_generate('<Expand-before>', item=TkTreectrl.ROOT)
        self.tree.bind('<ButtonRelease-1>', self.on_button1)
        self.win.activate()


    def close(self, event=None):
        result = []
        if event == 'OK':
            for prj in self.tree.item_children(TkTreectrl.ROOT):
                result = self.traverseTree( prj, result)
            #for l in result:
            #    print l
        self.win.destroy()
        self.result = result

    def traverseTree(self, node, result):
        #
        if not node == TkTreectrl.ROOT:
            names = [self.tree.item_text(node, self.treecol)[0] ]
        state = self.tree.itemstate_forcolumn(node, self.checkcol)
        if not state == None:
            names = [self.tree.item_text(node, self.treecol)[0] ]
            for parent in self.tree.item_ancestors(node)[:-1]:
                names.append(self.tree.item_text(parent, self.treecol)[0] )
            names.reverse()
            result.append(names)
            return result
        else:
            for child in self.tree.item_children(node):
                result = self.traverseTree(child, result)

        return result
        


    def expand(self, event):
        print "EXPANDING"
        item = event.item
        if not self.tree.item_numchildren(item) == 0:
            return

        t = event.widget
        ancestors = t.item_ancestors(item)
        if ancestors:
            generation = len(ancestors)
        else:
            generation = 0
        # if generation < 3 and generation > 0:
        #    self.tree.item_config(item, button=True)


        prj  = self._treeStyles['prj']
        #cell = self._treeStyles['cell']
        job  = self._treeStyles['job']
        
        if generation < 2:
            txt = prj['txt']
            img = prj['img']
            style = prj['style']
        else:
            txt = job['txt']
            img = job['img']
            style = job['style']


        if generation == 0:
            obj = self.history
        else:
            names = [ self.tree.item_text(item, self.treecol)[0]]
            #print "ANCESTOR", t.item_ancestors(item)
            for parent in t.item_ancestors(item)[:-1]:
                names.append(self.tree.item_text(parent, self.treecol)[0] )
            names.reverse()
            #print "NAME1", names
            obj = self.history
            for name in names:
                #print "OBJ", obj
                obj = obj[name]

        state = t.itemstate_forcolumn(item, self.checkcol)

        for child in obj.keys():
            button = generation < 2
            new = self.tree.create_item(parent=item, button=button, open=0)[0]
            self.tree.itemstyle_set(new, self.treecol, style)
            self.tree.itemstyle_set(new, self.checkcol, self.checkboxStyle)
            self.tree.itemelement_config(new, self.treecol, txt, text=child)
            
            if state is not None:
                t.itemstate_forcolumn(new, self.checkcol,state)

    def on_button1(self, event):
        t = event.widget
        identify = t.identify(event.x, event.y)
        
        if identify:
            try:
                item, column, element = identify[1], identify[3], identify[5]
                if int(column)==1: # The value column was pressed
                    ## handle button click on check buttons in columns 1 (i.e. values)
                    t.itemstate_forcolumn(item, column, '~Checked')
                    state = t.itemstate_forcolumn(item, self.checkcol)
                    self.propagateCheckButtonDown( item, state)
                    if state == None: # if uncheck, uncheck all ancestors
                        for parent in t.item_ancestors(item):
                            t.itemstate_forcolumn(parent, 1, '!Checked')
                    return 'break'
            except IndexError:
                pass

    def propagateCheckButtonDown(self, item, state):
        # go down the tree and check all buttons
        for child in self.tree.item_children(item):
            if state == None:
                if child:    
                    self.tree.itemstate_forcolumn(child, 1, '!Checked')
            else:
                if child:
                    self.tree.itemstate_forcolumn(child, 1, 'Checked')
            self.propagateCheckButtonDown(child, state)




if __name__ == '__main__':
    root = Tkinter.Tk()
    history = { 'prj1': 
                    {'exp1': 
                        { 'vs1':  [1,2,3]}, 
                     'exp2':
                        {'vs1': [2,3,4], 
                         'vs2':[9,8,7]
                         }} } 

    x = DictTreeCheckSelector(root, history)
    
    root.mainloop()




#       
#           AutoDock | Raccoon2
#
#       Copyright 2013, Stefano Forli
#          Molecular Graphics Lab
#  
#     The Scripps Research Institute 
#           _  
#          (,)  T  h e
#         _/
#        (.)    S  c r i p p s
#          \_
#          (,)  R  e s e a r c h
#         ./  
#        ( )    I  n s t i t u t e
#         '
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
import time
import sys
import getopt
import os
import user
import warnings
import stat
from string import split


from Support.version import __version__
from mglutil import __revision__
from mglutil.util.packageFilePath import setResourceFolder, getResourceFolder 

RACPATH = __path__[0]
ICONPATH = os.path.abspath(os.path.join(__path__[0], 'gui', 'icons'))
RESULTFILE = 'screening_report.log'

def createRoot():
    """ create a root and hide it
"""
    from Tkinter import Tk
    root = Tk()
    #root.withdraw()
    return root


def createRaccoon(root=None, interactive=True):
    """
    """
    from CADD.Raccoon2.gui import Raccoon2GUI
    rac = Raccoon2GUI.RaccoonGUI(parent=root)
    return rac


def createSplash():
    """
    """
    iconsDir = os.path.join( __path__[0], 'gui', 'icons')
    image_dir = os.path.join(__path__[0], 'gui', 'images')

    # insert release date here
    from Support.version import __version__
    from mglutil import __revision__
    version = ' ' + __version__

    copyright = """(c) 2013 Molecular Graphics Laboratory, The Scripps Research Institute
    ALL RIGHTS RESERVED """
    authors = """Authors: Stefano Forli, Michel Sanner"""
    icon = os.path.join( iconsDir, 'raccoon.png')
    third_party = """"""

    text = 'Python executable   : '+sys.executable+'\n'
    #text += 'Vision script               : '+__file__+'\n'
    text += 'MGLTool packages  : '+'\n'
    
    from user import home
    updates_rc_dir = home + os.path.sep + ".mgltools" + os.sep + 'update'
    latest_tested_rc = updates_rc_dir + os.sep + 'latest_tested'
    latest_rc = updates_rc_dir + os.sep + 'latest' #may or may not be tested
    
    if os.path.exists(latest_tested_rc):
        p = open(latest_tested_rc).read()
        sys.path.insert(0, p)
        text += '    tested  : ' + p +'\n'
    
    if os.path.exists(latest_rc):
        p = open(latest_rc).read()
        sys.path.insert(0, p)
        text += '    nightly : ' + p +'\n'
    
    text += version + ': ' + 'ADD PATH HERE'
    path_data = text

    from mglutil.splashregister.splashscreen import SplashScreen
    from CADD.Raccoon2.about import About
    about = About(image_dir=image_dir, third_party=third_party,
                  path_data=path_data,
                  title='Autodock | Raccoon2', version='1.0-beta',
                  revision='1', 
                  copyright=copyright, authors=authors, icon=icon)
    splash =  SplashScreen(about, noSplash=False)

    return splash, about
        

def runRaccoon(*argv, **kw):
    """
    The main function for running Raccoon
    """

    ##################################################################
    # Parse options
    ##################################################################

    if type(argv) is tuple:
        if len(argv) == 0:
            argv = None
        elif len(argv) == 1:
            argv = argv[0]
            if type(argv) is not list:
                argv = [argv]
        else:
            argv = list(argv)
    if kw.has_key("ownInterpreter"):
        ownInterpreter = kw["ownInterpreter"]
    else:
        if argv is None:
            argv = ['CADD/Raccoon2/bin/raccoonLauncher.py']
            ownInterpreter = False
        elif argv[0].endswith('raccoonLauncher.py') is False:
            argv.insert(0,'CADD/Raccoon2/bin/raccoonLauncher.py')
            ownInterpreter = False
        else:
            ownInterpreter = True

    help_msg = """usage: %s <options> <filenames>

    Files filenames ending in "net.py" will be laoded as networks in vision.
    Other files will be executed as Python scripts in which "ed" refers
    to the VisualProgrammingEnvironment instance.
    
            -h or --help : print this message
            -s or --noSplash : doesn't show the Vision splash screen (works only if registered)
            -t or --noTerminal : vision provides its own shell (under menu 'Edit') 
                           instead of the terminal
            --resourceFolder foldername  : stores resource file under .name (defaults to .mgltools)    
            -p or --ipython : create an ipython shell instead of a python shell        
            -r or --run  : run the networks on the command line
            -e or --runAndExit : run the networks and exit

            port values can be passed on the command line (but not to macros):
                             Network_net.py nodeName:portName:value

    """ % sys.argv[0]

    try:
        optlist, args = getopt.getopt(argv[1:], 'hirestp', [
            'help', 'interactive', 'noTerminal', 'noSplash', 'resourceFolder=', 'run', 'runAndExit','ipython'] )
    except:
        print "Unknown option!"
        print help_msg
        return

    interactive = 1
    noSplash = False
    runNetwork = False
    once = False
    ipython = False
    for opt in optlist:
        if opt[0] in ('-h', '--help'):
            print help_msg
            return
        elif opt[0] in ('-i', '--interactive'):
            warnings.warn('-i (interactive) is default mode, use --noTerminal to disable it',
                          stacklevel=3)
        elif opt[0] in ('-t', '--noTerminal'):
            interactive = 0
        elif opt[0] in ('-s', '--noSplash',):
            noSplash = True
        elif opt[0] in ('--resourceFolder',):
            setResourceFolder(opt[1])
        elif opt[0] in ('-r', '--run'):
            runNetwork = True
        elif opt[0] in ('-e', '--runAndExit'):
            runNetwork = True
            once = True
        elif opt[0] in ('-p', '--ipython'):
            ipython = True

    from Support.path import path_text, release_path
    print 'Run Raccoon from ', __path__[0]
    
    if globals().has_key('rac') is False:
        root = createRoot()
        root.withdraw()
        ##################################################################
        # Splash Screen
        ##################################################################
        if noSplash is False:
            splash, about = createSplash()
            lSplashVisibleTimeStart = time.clock()

        ##################################################################
        # Start Vision
        ##################################################################
        rac = createRaccoon(root, interactive)
        globals()['rac'] = rac

        ##################################################################
        # Source Resource File (if available)
        ##################################################################
        #if getResourceFolder() is None:
        #    print 'NO RESOURCE FOLDER'
        #else:
        #    print 'TODO source the raccon resource file'
        #    #rac.sourceFile(resourceFile='_visionrc')

        ##################################################################
        # Make sure splash is visible long enough before removing it
        ##################################################################
        if noSplash is False:
            lSplashVisibleTimeEnd = time.clock()
            while lSplashVisibleTimeEnd - lSplashVisibleTimeStart < 2:
                lSplashVisibleTimeEnd = time.clock()
            splash.finish()

        ##################################################################
        # Make vision visible 
        #(before the network loads, so the additional windows will load on top)
        ##################################################################
        if once is False:
            root.deiconify()

    else:
        rac = globals()['rac']
        #root = rac.master
        root.deiconify()
    lResults = []


    if once is True:
        ed.root.quit()
        ed.root.destroy()
        globals().pop('ed')
        return lResults
    ##################################################################
    # Set the Python Shell
    ##################################################################
    elif ownInterpreter is True:
        if interactive:
            sys.stdin = sys.__stdin__
            sys.stdout = sys.__stdout__
            sys.stderr = sys.__stderr__

            mod = __import__('__main__')
            if ipython is True:
                try:
                    # create IPython shell
                    from IPython.Shell import _select_shell
                    sh = _select_shell([])(argv=[], user_ns=mod.__dict__)
                    sh.mainloop()
                except:
                    import code
                    try: # hack to really exit code.interact 
                        code.interact( 'Raccoon Interactive Shell', local=mod.__dict__)
                    except:
                        pass
            else:
                import code
                try: # hack to really exit code.interact 
                    code.interact( 'Raccoon Interactive Shell', local=mod.__dict__)
                except:
                    pass

        else:
            root.mainloop()
    else:
        return lResults





import TkTreectrl, ImageTk, os, Tkinter, weakref
import tkFont

import sys
# Research
#   '- Projects ( "HIV", "HDAC-2", ....)
#        '- Experiment ( "protease fragments", "integrase_various", )
#             '- VirtualScreening ( "recname_libname" )

class Node:
    """
    Base class for a hierarchy of nodes
    """
    def __init__(self, name, childKlass):
        self.name = name
        self.parent = None
        self.childKlass = childKlass
        self.children = []


    def addChild(self, child):
        """
        """
        assert isinstance(child, self.childKlass), "Expecred %s instance, got %s" %(
            self.childKlass, child.__class__)
        self.children.append(child)
        child.parent = weakref.ref(self)


    def getChild(self, name):
        """
        """
        for child in self.children:
            if child.name==name: return child
        return None


    def delete(self):
        """
        """
        for c in self.children:
            c.delete()
        self.parent().children.remove(self)
        self.parent = None
        

    def traverseByType(self, ntype, results):
        """
        """
        if isinstance(self, ntype):
            return [self]
        for c in self.children:
            if isinstance(c, ntype):
                results.append(c)
            else:
                c.traverseByType(ntype, results)
        return results
    


class Research(Node):
    """
    """
    def __init__(self, name='NoName'):
        Node.__init__(self, name, Project)
        self.properties = {}


class Project(Node):

    def __init__(self, name):
        Node.__init__(self, name, Experiment)
        self.properties = {}


class Experiment(Node):
    """
    """
    def __init__(self, name):
        Node.__init__(self, name, VirtualScreening)
        self.properties = {}
        self.status = ''



class VirtualScreening(Node):
    """
    """
    def __init__(self, name, date, url, status, jobId, resurl): 
        """
        """
        Node.__init__(self, name, None)
        self.date = date
        self.properties = { 'job_type' : 'opal', # linux_cluster, local
                            'lig_library' : 'NCIdiv2',
                            'submission_date': '1/1/1970',
                            'results_location': '',
                            'receptor' : '',
                          }

        # OPAL service
        self.url = url
        self.status = status
        self.jobId = jobId
        self.resurl = resurl
        if resurl:
            self.properties['results_location'] = resurl

    def kill(self):
        import OpalClient
        server = OpalClient.OpalService(self.url)
        checker = OpalClient.JobStatus(server, self.jobId)
        if checker.isRunning():
            checker.destroyJob()
            self.status = 'Killed/Error'


    def getresurl(self):
        import OpalClient
        server = OpalClient.OpalService(self.url)
        checker = OpalClient.JobStatus(server, self.jobId)
        try:
            resurl = os.path.dirname(checker.getOutputFiles()[0])
        except:
            resurl  = '[ expired data? ]'
            #print "getresurl error", sys.exc_info()[1]
        return resurl
            
    def downloadres(self, path):
        import OpalClient
        server = OpalClient.OpalService(self.url)
        checker = OpalClient.JobStatus(server, self.jobId)
        try:
            checker.downloadOutput(path)
            return True
        except:
            return False

    def getfullname(self):
        """ return vs fullname  = [ prj_name, exp_name, vs_name ]"""
        #exp_name = self.parent.name
        #prj_name = self.parent.parent.name
        return [ self.parent().parent().name, self.parent().name, self.name ]
        


# project
#    virtual_screenings 
#       rec_vs ( rec + lig_lib )


class VSresultsTree:

    def __init__(self, root, fname=None, iconpath = None):

        import Pmw, Tkinter
        import TkTreectrl, ImageTk
        import os
        import tkFont
        import OpalClient
        #ICONPATH='icons/'
        family = 'Bitstream vera sans'
        #family = 'Arial'
        self.FONT = tkFont.Font(family=family,size=9)
        self.FONTlargebold = tkFont.Font(family=family,size=11, weight='bold')
        self.FONTbold = tkFont.Font(family=family,size=9,weight="bold")
        from CADD.Raccoon import ICONPATH
        
        self._iconpath=ICONPATH
        # print "UICONPATH", self._iconpath

        Tkinter.wantobjects=0
        self.root = root

        self._initTree()

        if fname:
            self.setDataFile(fname)
            #self._populateItems(fname)

            #self._activateTree()


    def traverse(self, node):
    
        if len(node.children)==0: # node is job
            #print 'JOB', node.name
            #query status and update tree for job
            return 'Succeess'

        results = []
        for child in node.children:
            results.append(self.traverse(child))

        ## all children of node have been visited
        #if isinstance(node, Experiment):
            #print 'VS', node.name, results
            # update VS status using results
        return results


##     def traverseByType(self, node, ntype = None, results = [] ):
##         """ traverse the graph returning all objects matching ntype """
##         if ntype == None:
##             return
##         if len(node.children) == 0:
##             return []

##         if isinstance(node, ntype):
##             if not node in results:
##                 results.append(node)

##         for child in node.children:
##             if isinstance(child, ntype):
##                 if not child in results:
##                     results.append(child)
##             self.traverseByType(child, ntype = ntype, results = results)
##         return results

    def findVsParent(self, vs):
        """ return the parent Experiment of the VS """
        prj_list = []
        self.traverseByType( self.research, ntype = Experiment, 
            results = prj_list)
        for p in prj_list:
            if vs in p.children:
                return p
        return None


    def buildGraph(self, node, useName=True):
        # NOTE store c.name or c as obj?
        results = {}
        if hasattr(node, 'children'):
            for c in node.children:
                if useName:
                    key = c.name
                else:
                    key = c
                results[key] = self.buildGraph(self.buildGraph(c), useName=useName)
        else:
            return node
        return results

    def getTreeGraph(self, useName=True):
        return self.buildGraph(self.research, useName=useName)


    def setDataFile(self, fname):
        self._populateItems(fname)
        self._activateTree()

    def _activateTree(self):
        self._buildTree()
        self.tree.notify_generate('<Expand-before>', item=TkTreectrl.ROOT)
        self.tree.see(TkTreectrl.ROOT)


    def _populateItems(self, fname):

        f = open(fname)
        data = f.readlines()
        f.close()

        try:
            projects ={}
            for line in data:
                word = [w.strip()[1:-1] for w in line.split('\t')]
                project = word[0]
                experiment = word[1]
                receptor = word[2]
                date = word[3]
                url = word[4]
                status = word[5]
                jobId = word[6]
                resurl = word[7]
                try:
                    reslocation = word[8]
                except:
                    reslocation = "" 
                # XXX PROBABLY OBSOLETE
                try:
                    hidden = words[9]
                except:
                    hidden = ''

                proj = projects.get(project, None)
                if proj is None:
                    pro = Project(project)
                    self.research.addChild(pro)
                    exp = Experiment(experiment)
                    pro.addChild(exp)
                    projects[project] = pro
                else:
                    pro = projects[project]
                    exp = pro.getChild(experiment)
                    if exp is None:
                        exp = Experiment(experiment)
                        pro.addChild(exp)
                        
                job = VirtualScreening( receptor, date, url, status, jobId, resurl)
                job.properties['results_location'] = reslocation
                exp.addChild(job)
        except:
            print "ERROR: PrjManagerTree|_populateItems> possible old version file format for history (missing columns?)"
            return
    
    

    def _initTree(self):
        #print "INIT TREE"
        self.treeObj = TkTreectrl.ScrolledTreectrl(self.root)
        self.treeObj.pack(expand=1,fill='both')
        self.tree = self.treeObj.treectrl

        self.research = Research()
        self.tree.itemToObj={ TkTreectrl.ROOT : self.research } # gives obj from tree items
        self.tree.objToItem = {self.research : TkTreectrl.ROOT} # give tree items from obj



    def _buildTree(self):

        self.tree.columns = []
        #jobname_col= self.tree.column_create(text="jobname")
        jobname_col= self.tree.column_create(text="")
        self.tree.columns.append(jobname_col)
        self.tree.configure(treecolumn=jobname_col, showbuttons=1, font=self.FONT)
        self.tree.columns.append(self.tree.column_create(text='status', expand=1))
        self.tree.columns.append(self.tree.column_create(text='date', expand=1))
        self.tree.columns.append(self.tree.column_create(text='service URL', expand=0))
        self.tree.columns.append(self.tree.column_create(text='jobId', expand=0))
        self.tree.columns.append(self.tree.column_create(text='results URL', expand=0))

        #checkedIcon = self.tree.icons['checkedIcon'] = \
        #            Tkinter.PhotoImage(master=master, data='R0lGODlhDQANABEAACwAAAAADQANAIEAAAB/f3/f39////8CJ4yPNgHtLxYYtNbIbJ146jZ0gzeCIuhQ53NJVNpmryZqsYDnemT3BQA7')
        self._molIcon = molIcon = ImageTk.PhotoImage(
                    file=os.path.join(self._iconpath, 'water2.png'))
        self._cogIcon = cogIcon = ImageTk.PhotoImage(
                    file=os.path.join(self._iconpath, 'system.png'))

        self._jobIcon = jobIcon =  ImageTk.PhotoImage(
                    file=os.path.join(self._iconpath, 'basket.png'))

        self._treeStyles = {}

        # text style

        # style for project
        styleProject = self.tree.style_create()
        pel_image = self.tree.element_create(type=TkTreectrl.IMAGE,
                                    image=(molIcon, TkTreectrl.OPEN, molIcon, ''))

        pel_text = self.tree.element_create(type=TkTreectrl.TEXT,  fill=('white', TkTreectrl.SELECTED))
        pel_select = self.tree.element_create(type=TkTreectrl.RECT, showfocus=1,
                                     fill=('blue4', TkTreectrl.SELECTED))
        self.tree.style_elements(styleProject, pel_image, pel_select, pel_text)
        self.tree.style_layout(styleProject, pel_image, pady=1)
        self.tree.style_layout(styleProject, pel_select, union=(pel_text,), padx=1, pady=1, squeeze='')
        self.tree.style_layout(styleProject, pel_text, padx=1, pady=1, ipadx=2,ipady=2) #, squeeze='y')
        self.tree.itemstyle_set(TkTreectrl.ROOT, jobname_col, styleProject)
        self.tree.itemelement_config(TkTreectrl.ROOT, jobname_col, pel_text, text='Raccoon jobs',
                                    font =self.FONTlargebold)
                                     #datatype=TkTreectrl.STRING, data='top')
        self._treeStyles['prj'] = { 'img' : pel_image, 'txt' : pel_text, 'style' : styleProject}



        # style for jobs
        styleJob = self.tree.style_create()
        job_image = self.tree.element_create(type=TkTreectrl.IMAGE,
                                    image=(jobIcon, TkTreectrl.OPEN, jobIcon, ''))
        #pel_text = self.tree.element_create(type=TkTreectrl.TEXT,  fill=('white', TkTreectrl.SELECTED))
        self.tree.style_elements(styleJob, job_image, pel_select, pel_text)
        self.tree.style_layout(styleJob, pel_select, union=(pel_text,), padx=1, pady=1, ipadx=1,ipady=1 ) #, squeeze='y')
        self.tree.style_layout(styleJob, job_image, pady=2)
        self._treeStyles['job'] = { 'img' : job_image, 'txt' : pel_text, 'style' : styleJob}




        # style for string cell
        styleString = self.tree.style_create()
        cel_text = self.tree.element_create(type=TkTreectrl.TEXT,  fill=('white', TkTreectrl.SELECTED))
        #el_text = self.tree.element_create(type=TkTreectrl.TEXT)
        #cel_image = self.tree.element_create(type=TkTreectrl.IMAGE,
        #                            image=(molIcon, TkTreectrl.OPEN, molIcon, ''))
        #el_select1 = self.tree.element_create(type=TkTreectrl.RECT, showfocus=1,
        #                             fill=('blue4', TkTreectrl.SELECTED))
        self.tree.style_elements(styleString, pel_select, cel_text)
        self.tree.style_layout(styleString, cel_text, padx=1, pady=1, squeeze='y')
        self.tree.style_layout(styleString, pel_select, union=(cel_text,), padx=1, pady=1, ipadx=1,ipady=1 )
        #self.tree.itemstyle_set(TkTreectrl.ROOT, jobname_col, styleProject)

        self._treeStyles['cell'] = { 'txt' : cel_text, 'style' : styleString}



    


        


        # bindings
        self.tree.notify_bind('<Expand-before>', self.expandNode_cb)

        #self.tree.bind('<Double-Button-1>', self.on_button1)
        #self.tree.bind('<ButtonRelease-3>', self.on_button3)
                

    def expandNode_cb(self, event):
        #print "prj EXAPAND NODECB"
        item = event.item
        obj = self.tree.itemToObj.get(item, None)
        self.expandNode(obj)
            


    def expandNode(self, obj):
        item = self.tree.objToItem.get(obj, None)
        if item is None:
            raise RuntimeError ('expanding node without item')
    
        if self.tree.item_numchildren(item)==len(obj.children):
            #print "ITEMCHILD", self.tree.item_numchildren(item)
            # directory has already been drawn, don't bother to track changes to the directory structure here
            #print 'RETURN because already expanded'
            return

        if len(obj.children):
            self.tree.item_config(item, button=True)

        prj  = self._treeStyles['prj']
        cell = self._treeStyles['cell']
        job  = self._treeStyles['job']

        p_txt = prj['txt']
        p_img = prj['img']
        p_style = prj['style']
        c_txt = cell['txt']
        c_style = cell['style']

        # that's a trick: store the item's full path in the text element's data option
        #data = self.tree.itemelement_cget(item, self.tree.columns[0], p_txt , 'data')

        #print "data:", data
        #print 'obj :', obj
        
        #print "el_TEXT", p_txt
        for child in obj.children:
            if self.tree.objToItem.has_key(child):
                #print 'SKIPPING', child.name
                continue
            #print "==> child:", child.name, child
            button = len(child.children) > 0
            #print "CHILDREN", len(child.children)
            new = self.tree.create_item(parent=item, button=button, open=0)[0]
            # create bi-directional lookup
            self.tree.itemToObj[new] = child
            self.tree.objToItem[child] = new 
            #self.tree.itemstyle_set(new, self.tree.columns[0], styleProject)
            self.tree.itemstyle_set(new, self.tree.columns[0], p_style)
            self.tree.itemelement_config(new, self.tree.columns[0], p_txt, text=child.name, font=self.FONTbold)
            if isinstance(child, Experiment):
                #print "VS", child

                self.tree.itemstyle_set(new, self.tree.columns[1], c_style)
                nbSuccess = nbFail = nbRunning = 0
                for c in child.children:
                    "CSTATUS", c.status
                    if c.status=='Successful': nbSuccess +=1
                    elif c.status=='Fail': nbnbFail +=1
                    elif c.status=='Running': nbRunning +=1
                if nbSuccess==len(child.children) and nbSuccess > 0:
                    status = 'Successful'
                    status = 'SUCCESSFUL'
                    color = '#33bb33'
                elif nbFail==len(child.children) and nbFail > 0:
                    status = 'FAIL'
                    color = 'red'
                elif nbRunning == len(child.children) and nbRunning > 0:
                    status = 'RUNNING'
                    color = 'orange'
                else:
                    status = 'PARTIAL'
                    color = 'orange'
                color = 'black'
                child.status = status
                self.tree.itemelement_config(new, self.tree.columns[1], c_txt, text=status, fill=(color,),font=self.FONTbold)

            elif isinstance(child, VirtualScreening):
                style = job['style']
                text = job['txt']
                img = job['img']
                #self._treeStyles['job'] = { 'img' : job_image, 'txt' : pel_text, 'style' : styleJob}
                #print child
                self.tree.itemstyle_set(new, self.tree.columns[0], style)
                self.tree.itemelement_config(new, self.tree.columns[0], text, text=child.name, fill=('black',), font=self.FONT)
                text = cell['txt']
                style = cell['style']
                self.tree.itemstyle_set(new, self.tree.columns[1], style)
                self.tree.itemelement_config(new, self.tree.columns[1], text, text=child.status, fill=('black',), font =self.FONT )
                self.tree.itemstyle_set(new, self.tree.columns[2], style)
                self.tree.itemelement_config(new, self.tree.columns[2], text, text=child.date, fill=('black',), font=self.FONT)
                self.tree.itemstyle_set(new, self.tree.columns[3], style)
                self.tree.itemelement_config(new, self.tree.columns[3], text, text=child.url, fill=('black',), font=self.FONT)
                self.tree.itemstyle_set(new, self.tree.columns[4], style)
                self.tree.itemelement_config(new, self.tree.columns[4], text, text=child.jobId, fill=('black',), font=self.FONT)
                self.tree.itemstyle_set(new, self.tree.columns[5], style)
                self.tree.itemelement_config(new, self.tree.columns[5], text, text=child.resurl, fill=('black',), font=self.FONT)


if __name__ == '__main__':
    import Pmw, Tkinter
    import TkTreectrl, ImageTk
    import os
    ICONPATH='.'
    print "START"
    fname = '/entropia/.mgltools/latest/Raccoon/raccoon_opal.hist'
    fname = 'raccoon_opal.hist'
    fname ='null'
    root = Tkinter.Tk()
    vst = VSresultsTree(root, fname)



#!/bin/ksh ~/.mgltools/pythonsh
########################################################################
#
#    Vision Network - Python source code - file generated by vision
#    Monday 14 February 2011 12:31:28 
#    
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Daniel Stoffler, Michel Sanner and TSRI
#   
# revision: Guillaume Vareille
#  
#########################################################################
#
# $Header: /opt/cvs/CADD/workflows/virtualScreening/AutoDockML_0.1_net.py,v 1.1 2011/04/15 16:19:38 nadya Exp $
#
# $Id: AutoDockML_0.1_net.py,v 1.1 2011/04/15 16:19:38 nadya Exp $
#


if __name__=='__main__':
    from sys import argv
    if '--help' in argv or '-h' in argv or '-w' in argv: # run without Vision
        withoutVision = True
        from Vision.VPE import NoGuiExec
        ed = NoGuiExec()
        from NetworkEditor.net import Network
        import os
        masterNet = Network("process-"+str(os.getpid()))
        ed.addNetwork(masterNet)
    else: # run as a stand alone application while vision is hidden
        withoutVision = False
        from Vision import launchVisionToRunNetworkAsApplication, mainLoopVisionToRunNetworkAsApplication
	if '-noSplash' in argv:
	    splash = False
	else:
	    splash = True
        masterNet = launchVisionToRunNetworkAsApplication(splash=splash)
        import os
        masterNet.filename = os.path.abspath(__file__)
from traceback import print_exc
## loading libraries ##
from AutoDockTools.VisionInterface.Adt import Adt
from WebServices.VisionInterface.WSNodes import wslib
from Vision.StandardNodes import stdlib
try:
    masterNet
except (NameError, AttributeError): # we run the network outside Vision
    from NetworkEditor.net import Network
    masterNet = Network()

masterNet.getEditor().addLibraryInstance(Adt,"AutoDockTools.VisionInterface.Adt", "Adt")

masterNet.getEditor().addLibraryInstance(wslib,"WebServices.VisionInterface.WSNodes", "wslib")

masterNet.getEditor().addLibraryInstance(stdlib,"Vision.StandardNodes", "stdlib")

from WebServices.VisionInterface.WSNodes import addOpalServerAsCategory
try:
    addOpalServerAsCategory("http://kryptonite.nbcr.net/opal2", replace=False)
except:
    pass
try:
    ## saving node AutodockVS ##
    from Adt.Macro.AutodockVS import AutodockVS
    AutodockVS_0 = AutodockVS(constrkw={}, name='AutodockVS', library=Adt)
    masterNet.addNode(AutodockVS_0,357,292)
    apply(AutodockVS_0.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
    autodock_kryptonite_nbcr_net_4 = AutodockVS_0.macroNetwork.nodes[3]
    autodock_kryptonite_nbcr_net_4.inputPortByName['ga_run'].widget.set(r"", run=False)
    apply(autodock_kryptonite_nbcr_net_4.inputPortByName['lib'].widget.configure, (), {'choices': ('sample', 'NCIDS_SC', 'NCI_DS1', 'NCI_DS2', 'human_metabolome', 'chembridge_building_blocks', 'drugbank_nutraceutics', 'drugbank_smallmol', 'fda_approved')})
    autodock_kryptonite_nbcr_net_4.inputPortByName['lib'].widget.set(r"", run=False)
    autodock_kryptonite_nbcr_net_4.inputPortByName['filter_file_url'].widget.set(r"", run=False)
    autodock_kryptonite_nbcr_net_4.inputPortByName['ga_num_evals'].widget.set(r"", run=False)
    apply(autodock_kryptonite_nbcr_net_4.inputPortByName['sched'].widget.configure, (), {'choices': ('SGE', 'CSF')})
    autodock_kryptonite_nbcr_net_4.inputPortByName['sched'].widget.set(r"SGE", run=False)
    autodock_kryptonite_nbcr_net_4.inputPortByName['ga_num_generations'].widget.set(r"", run=False)
    autodock_kryptonite_nbcr_net_4.inputPortByName['userlib'].widget.set(r"", run=False)
    autodock_kryptonite_nbcr_net_4.inputPortByName['ga_pop_size'].widget.set(r"", run=False)
    autodock_kryptonite_nbcr_net_4.inputPortByName['localRun'].widget.set(0, run=False)
    autodock_kryptonite_nbcr_net_4.inputPortByName['email'].widget.set(r"", run=False)
    autodock_kryptonite_nbcr_net_4.inputPortByName['execPath'].widget.set(r"", run=False)

    ## saving connections for network AutodockVS ##
    AutodockVS_0.macroNetwork.freeze()
    AutodockVS_0.macroNetwork.unfreeze()

    ## modifying MacroInputNode dynamic ports
    input_Ports_1 = AutodockVS_0.macroNetwork.ipNode
    input_Ports_1.outputPorts[1].configure(name='PrepareADVSInputs_ligands')
    input_Ports_1.outputPorts[2].configure(name='PrepareADVSInputs_autogrid_results')
    input_Ports_1.outputPorts[3].configure(name='PrepareADVSInputs_dpf_template_obj')

    ## modifying MacroOutputNode dynamic ports
    output_Ports_2 = AutodockVS_0.macroNetwork.opNode
    output_Ports_2.inputPorts[1].configure(singleConnection='auto')
    output_Ports_2.inputPorts[1].configure(name='GetMainURLFromList_newurl')
    AutodockVS_0.inputPorts[0].configure(name='PrepareADVSInputs_ligands')
    AutodockVS_0.inputPorts[0].configure(datatype='LigandDB')
    AutodockVS_0.inputPorts[1].configure(name='PrepareADVSInputs_autogrid_results')
    AutodockVS_0.inputPorts[1].configure(datatype='autogrid_results')
    AutodockVS_0.inputPorts[2].configure(name='PrepareADVSInputs_dpf_template_obj')
    AutodockVS_0.inputPorts[2].configure(datatype='dpf_template')
    ## configure MacroNode input ports
    AutodockVS_0.outputPorts[0].configure(name='GetMainURLFromList_newurl')
    AutodockVS_0.outputPorts[0].configure(datatype='string')
    ## configure MacroNode output ports
    AutodockVS_0.shrink()
    apply(AutodockVS_0.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
except:
    print "WARNING: failed to restore AutodockVS named AutodockVS in network masterNet"
    print_exc()
    AutodockVS_0=None

try:
    ## saving node DownloadSaveDir ##
    from WebServices.VisionInterface.WSNodes import DownloadSaveDirNode
    DownloadSaveDir_6 = DownloadSaveDirNode(constrkw={}, name='DownloadSaveDir', library=wslib)
    masterNet.addNode(DownloadSaveDir_6,357,391)
    apply(DownloadSaveDir_6.inputPortByName['url'].configure, (), {'defaultValue': None})
    DownloadSaveDir_6.inputPortByName['url'].rebindWidget()
    DownloadSaveDir_6.inputPortByName['url'].widget.set(r"", run=False)
    DownloadSaveDir_6.inputPortByName['url'].unbindWidget()
    apply(DownloadSaveDir_6.configure, (), {'paramPanelImmediate': 1})
except:
    print "WARNING: failed to restore DownloadSaveDirNode named DownloadSaveDir in network masterNet"
    print_exc()
    DownloadSaveDir_6=None

try:
    ## saving node Output_Directory ##
    from Vision.StandardNodes import DirBrowserNE
    Output_Directory_7 = DirBrowserNE(constrkw={}, name='Output_Directory', library=stdlib)
    masterNet.addNode(Output_Directory_7,547,265)
    Output_Directory_7.inputPortByName['directory'].widget.set(r"AutoDockML_0.1_output", run=False)
    apply(Output_Directory_7.configure, (), {'paramPanelImmediate': 1})
except:
    print "WARNING: failed to restore DirBrowserNE named Output_Directory in network masterNet"
    print_exc()
    Output_Directory_7=None

try:
    ## saving node AutogridResURL ##
    from Adt.Input.AutogridResURL import AutogridResURL
    AutogridResURL_8 = AutogridResURL(constrkw={}, name='AutogridResURL', library=Adt)
    masterNet.addNode(AutogridResURL_8,374,145)
    AutogridResURL_8.inputPortByName['url'].widget.set(r"http://kryptonite.nbcr.net/appautogrid1296246047469-570974390/", run=False)
    apply(AutogridResURL_8.configure, (), {'paramPanelImmediate': 1})
except:
    print "WARNING: failed to restore AutogridResURL named AutogridResURL in network masterNet"
    print_exc()
    AutogridResURL_8=None

try:
    ## saving node PublicServerLigandDB ##
    from Adt.Input.PublicServerLigandDB import PublicServerLigandDB
    PublicServerLigandDB_9 = PublicServerLigandDB(constrkw={}, name='PublicServerLigandDB', library=Adt)
    masterNet.addNode(PublicServerLigandDB_9,13,145)
    PublicServerLigandDB_9.inputPortByName['server_lib'].widget.set(r"sample", run=False)
except:
    print "WARNING: failed to restore PublicServerLigandDB named PublicServerLigandDB in network masterNet"
    print_exc()
    PublicServerLigandDB_9=None

try:
    ## saving node DPFTemplateBrowser ##
    from Adt.Input.DPFTemplateBrowser import DPFTemplateBrowser
    DPFTemplateBrowser_10 = DPFTemplateBrowser(constrkw={}, name='DPFTemplateBrowser', library=Adt)
    masterNet.addNode(DPFTemplateBrowser_10,915,143)
    DPFTemplateBrowser_10.inputPortByName['dpf_template_file'].widget.set(r"AutoDockML_0.1_input/2HTY_A.dpf", run=False)
    apply(DPFTemplateBrowser_10.configure, (), {'paramPanelImmediate': 1})
except:
    print "WARNING: failed to restore DPFTemplateBrowser named DPFTemplateBrowser in network masterNet"
    print_exc()
    DPFTemplateBrowser_10=None

#masterNet.run()
masterNet.freeze()

## saving connections for network AutoDockML-0.1 ##
if Output_Directory_7 is not None and DownloadSaveDir_6 is not None:
    try:
        masterNet.connectNodes(
            Output_Directory_7, DownloadSaveDir_6, "directory", "path", blocking=True
            , splitratio=[0.65546942220461224, 0.32042606395899709])
    except:
        print "WARNING: failed to restore connection between Output_Directory_7 and DownloadSaveDir_6 in network masterNet"
if AutodockVS_0 is not None and DownloadSaveDir_6 is not None:
    try:
        masterNet.connectNodes(
            AutodockVS_0, DownloadSaveDir_6, "GetMainURLFromList_newurl", "url", blocking=True
            , splitratio=[0.2182585732109612, 0.71171057897582179])
    except:
        print "WARNING: failed to restore connection between AutodockVS_0 and DownloadSaveDir_6 in network masterNet"
if PublicServerLigandDB_9 is not None and AutodockVS_0 is not None:
    try:
        masterNet.connectNodes(
            PublicServerLigandDB_9, AutodockVS_0, "ligDB", "PrepareADVSInputs_ligands", blocking=True
            , splitratio=[0.21870434345807416, 0.66803683999749475])
    except:
        print "WARNING: failed to restore connection between PublicServerLigandDB_9 and AutodockVS_0 in network masterNet"
if AutogridResURL_8 is not None and AutodockVS_0 is not None:
    try:
        masterNet.connectNodes(
            AutogridResURL_8, AutodockVS_0, "autogrid_res_obj", "PrepareADVSInputs_autogrid_results", blocking=True
            , splitratio=[0.44788171325418591, 0.35372301560992558])
    except:
        print "WARNING: failed to restore connection between AutogridResURL_8 and AutodockVS_0 in network masterNet"
if DPFTemplateBrowser_10 is not None and AutodockVS_0 is not None:
    try:
        masterNet.connectNodes(
            DPFTemplateBrowser_10, AutodockVS_0, "dpf_template", "PrepareADVSInputs_dpf_template_obj", blocking=True
            , splitratio=[0.33272690695264329, 0.20368928127553113])
    except:
        print "WARNING: failed to restore connection between DPFTemplateBrowser_10 and AutodockVS_0 in network masterNet"
masterNet.runOnNewData.value = False

if __name__=='__main__':
    from sys import argv
    lNodePortValues = []
    if (len(argv) > 1) and argv[1].startswith('-'):
        lArgIndex = 2
    else:
        lArgIndex = 1
    while lArgIndex < len(argv) and argv[lArgIndex][-3:]!='.py':
        lNodePortValues.append(argv[lArgIndex])
        lArgIndex += 1
    masterNet.setNodePortValues(lNodePortValues)
    if '--help' in argv or '-h' in argv: # show help
        masterNet.helpForNetworkAsApplication()
    elif '-w' in argv: # run without Vision and exit
         # create communicator
        from NetworkEditor.net import Communicator
        masterNet.communicator = Communicator(masterNet)
        print 'Communicator listening on port:', masterNet.communicator.port

        import socket
        f = open(argv[0]+'.sock', 'w')
        f.write("%s %i"%(socket.gethostbyname(socket.gethostname()),
                         masterNet.communicator.port))
        f.close()

        masterNet.run()

    else: # stand alone application while vision is hidden
        if '-e' in argv: # run and exit
            masterNet.run()
        elif '-r' in argv or len(masterNet.userPanels) == 0: # no user panel => run
            masterNet.run()
            mainLoopVisionToRunNetworkAsApplication(masterNet.editor)
        else: # user panel
            mainLoopVisionToRunNetworkAsApplication(masterNet.editor)

